## API: /send_private_msg

### 概述

此接口用于向指定的QQ用户发送私聊消息。

### Endpoint

`POST /send_private_msg`

### 请求体 (Request Body)

接口接受一个 JSON 对象作为请求体，包含以下必填参数：

| 字段名    | 类型         | 描述                 | 是否必填 |
| :-------- | :----------- | :------------------- | :------- |
| `user_id` | `number` 或 `string` | 接收消息的QQ用户ID。 | 是       |
| `message` | `array`      | 消息内容，由一个或多个消息段组成。 | 是       |

#### `message` 字段详解

`message` 字段是一个数组，数组的每个元素代表一个消息段。一个消息可以由多种类型的消息段组成，例如文本、图片、表情等。支持的消息段类型如下：

*   **文本消息 (`text`)**
    *   `type`: `string` (固定为 `"text"`)
    *   `data`: `object`
        *   `text`: `string` (文本内容)
    *   示例:
        ```json
        {
          "type": "text",
          "data": {
            "text": "你好，这是一条文本消息。"
          }
        }
        ```

*   **表情消息 (`face`)**
    *   `type`: `string` (固定为 `"face"`)
    *   `data`: `object`
        *   `id`: `number` (表情ID)
    *   示例:
        ```json
        {
          "type": "face",
          "data": {
            "id": 100
          }
        }
        ```

*   **图片消息 (`image`)**
    *   `type`: `string` (固定为 `"image"`)
    *   `data`: `object`
        *   `file`: `string` (图片文件路径、URL 或 Base64 编码)
        *   `summary`: `string` (可选，图片的简要描述，外显用，默认为 `[图片]`)
    *   示例:
        ```json
        {
          "type": "image",
          "data": {
            "file": "https://example.com/image.jpg",
            "summary": "一张美丽的图片"
          }
        }
        ```

*   **回复消息 (`reply`)**
    *   `type`: `string` (固定为 `"reply"`)
    *   `data`: `object`
        *   `id`: `string` 或 `number` (要回复的消息ID)
    *   示例:
        ```json
        {
          "type": "reply",
          "data": {
            "id": 123456
          }
        }
        ```

*   **JSON消息 (`json`)**
    *   `type`: `string` (固定为 `"json"`)
    *   `data`: `object`
        *   `data`: `string` (JSON 结构的字符串)
    *   示例:
        ```json
        {
          "type": "json",
          "data": {
            "data": "{\"key\": \"value\", \"list\": [1, 2, 3]}"
          }
        }
        ```

*   **语音消息 (`record`)**
    *   `type`: `string` (固定为 `"record"`)
    *   `data`: `object`
        *   `file`: `string` (语音文件路径、URL 或 Base64 编码)
    *   示例:
        ```json
        {
          "type": "record",
          "data": {
            "file": "file:///path/to/audio.amr"
          }
        }
        ```

*   **视频消息 (`video`)**
    *   `type`: `string` (固定为 `"video"`)
    *   `data`: `object`
        *   `file`: `string` (视频文件路径、URL 或 Base64 编码)
    *   示例:
        ```json
        {
          "type": "video",
          "data": {
            "file": "file:///path/to/video.mp4"
          }
        }
        ```

*   **Markdown消息 (内部类型为 `record`)**
    *   `type`: `string` (固定为 `"record"`)
    *   `data`: `object`
        *   `content`: `string` (Markdown 格式的文本内容)
    *   *注意: 根据提供的Schema，Markdown消息的类型被定义为 `record`。*
    *   示例:
        ```json
        {
          "type": "record",
          "data": {
            "content": "# 这是一级标题\n\n- 列表项1\n- 列表项2"
          }
        }
        ```

#### 请求体示例

发送一条包含文本和图片的私聊消息：

```json
{
  "user_id": 123456789,
  "message": [
    {
      "type": "text",
      "data": {
        "text": "你好！"
      }
    },
    {
      "type": "image",
      "data": {
        "file": "https://example.com/greeting.jpg"
      }
    }
  ]
}
```

### 响应 (Response)

#### 成功响应 (状态码: 200)

接口成功调用时，将返回以下 JSON 结构：

| 字段名    | 类型     | 描述                               | 示例值     |
| :-------- | :------- | :--------------------------------- | :--------- |
| `status`  | `string` | 状态码，固定为 `"ok"` 表示成功。 | `"ok"`   |
| `retcode` | `number` | 返回码，表示具体的操作结果。     | `0`        |
| `data`    | `object` | 响应数据。                         | `{ ... }`  |
| `message` | `string` | 错误信息（当 status 不为 `ok` 时） | `""`       |
| `wording` | `string` | 错误信息的友好描述（当 status 不为 `ok` 时） | `""`       |
| `echo`    | `string` 或 `null` | 请求的 echo 字段，如果请求中携带了的话。 | `""` 或 `null` |

##### `data` 字段详解

当 `status` 为 `ok` 时，`data` 字段包含以下内容：

| 字段名      | 类型     | 描述   | 是否必填 |
| :---------- | :------- | :----- | :------- |
| `message_id` | `number` | 发送成功的消息ID。 | 是       |

#### 成功响应示例

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 987654321
  },
  "message": "",
  "wording": "",
  "echo": null
}
```

### 错误处理

当 `status` 不为 `ok` 时，`retcode` 将指示具体的错误原因，`message` 和 `wording` 字段将提供错误详情。
