## API 文档: `/send_group_msg`

### 接口概述

发送群消息到指定的QQ群。

### Endpoint

`POST /send_group_msg`

### 描述

用于向指定的QQ群发送各种类型的消息，支持多种消息段组合发送。

### 请求体 (Request Body)

使用 `application/json` 格式。

| 字段名    | 类型          | 必须 | 说明         |
| :-------- | :------------ | :--- | :----------- |
| `group_id`| number 或 string | 是   | 群号         |
| `message` | array         | 是   | 消息内容，一个消息段数组。支持的消息段类型见下方说明。 |

**`message` 字段说明**

`message` 字段是一个数组，数组中的每个元素代表一个消息段。支持以下消息段类型：

#### 1. 文本消息

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"text"` |
| `data` | object |          |
| `data.text` | string | 文本内容 |

**示例:**
```json
{
  "type": "text",
  "data": {
    "text": "这是一段文本消息"
  }
}
```

#### 2. At 消息

艾特群成员或全体成员。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"at"` |
| `data` | object |          |
| `data.qq` | string 或 number 或 `"all"` | 要艾特的QQ号，或 `"all"` 表示艾特全体 |
| `data.name` | string | 艾特时显示的名字 (可选) |

**示例:**
```json
{
  "type": "at",
  "data": {
    "qq": "123456789"
  }
}
```

#### 3. 表情消息

发送QQ内置表情。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |\n| `type` | string | 固定为 `"face"` |
| `data` | object |          |
| `data.id` | number | 表情ID |

**示例:**
```json
{
  "type": "face",
  "data": {
    "id": 100
  }
}
```

#### 4. 图片消息

发送图片。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"image"` |
| `data` | object |          |
| `data.file` | string | 图片文件路径、URL 或 Base64 数据 |
| `data.summary` | string | 图片的外显描述 (可选，默认 `[图片]`) |

**示例:**
```json
{
  "type": "image",
  "data": {
    "file": "https://example.com/image.jpg",
    "summary": "美丽的图片"
  }
}
```

#### 5. 回复消息

回复指定消息。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"reply"` |
| `data` | object |          |
| `data.id` | string 或 number | 要回复的消息的ID |

**示例:**
```json
{
  "type": "reply",
  "data": {
    "id": 123456789
  }
}
```

#### 6. JSON 消息

发送自定义 JSON 结构的消息（如分享链接等）。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"json"` |
| `data` | object |          |
| `data.data` | string | JSON 字符串 |

**示例:**
```json
{
  "type": "json",
  "data": {
    "data": "{\"app\":\"com.tencent.miniapp\", ...}"
  }
}
```

#### 7. 语音消息

发送语音。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"record"` *注意: 类型名为 `record`* |
| `data` | object |          |
| `data.file` | string | 语音文件路径、URL 或 Base64 数据 |

**示例:**
```json
{
  "type": "record",
  "data": {
    "file": "file:///path/to/voice.amr"
  }
}
```

#### 8. 视频消息

发送视频。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"video"` |
| `data` | object |          |
| `data.file` | string | 视频文件路径、URL 或 Base64 数据 |

**示例:**
```json
{
  "type": "video",
  "data": {
    "file": "file:///path/to/video.mp4"
  }
}
```

#### 9. Markdown 消息

发送 Markdown 格式消息。

| 字段名 | 类型   | 说明     |
| :----- | :----- | :------- |
| `type` | string | 固定为 `"record"` *注意: 类型名为 `record`* |
| `data` | object |          |
| `data.content` | string | Markdown 文本内容 |

**示例:**
```json
{
  "type": "record",
  "data": {
    "content": "# 这是一个标题\n**粗体文本**"
  }
}
```

### 响应体 (Response Body)

成功响应使用 `application/json` 格式，遵循标准响应结构。

| 字段名  | 类型    | 说明     |
| :------ | :------ | :------- |
| `status`| string  | 状态码，成功时为 `"ok"` |
| `retcode`| number  | 返回码，0 表示成功 |
| `data`  | object  | 业务数据 |
| `message`| string  | 错误信息，成功时为空字符串 |
| `wording`| string  | 错误信息的易读版本，成功时为空字符串 |
| `echo`  | string or null | 请求时携带的 echo 字段 |

**`data` 字段说明**

`data` 字段是一个对象，包含本次发送消息的结果信息：

| 字段名      | 类型   | 说明     |
| :---------- | :----- | :------- |
| `message_id`| number | 发送成功的消息ID |

**成功响应示例:**
```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 696124706
  },
  "message": "",
  "wording": ""
}
```

### 错误处理

接口会返回标准错误响应，`status` 字段为非 `"ok"`，`retcode` 为非 0 的数字，`message` 和 `wording` 字段包含错误详细信息。
