# API: /send_msg

## 说明
发送消息。

根据 `message_type` 发送私聊或群聊消息。消息内容为消息段数组。

## Endpoint
`POST /send_msg`

## 请求参数

| 参数名         | 类型     | 是否必须 | 说明                                      |
| -------------- | -------- | -------- | ----------------------------------------- |
| `message_type` | string   | 是       | 消息类型，可选值: `group` (群聊) 或 `private` (私聊) |
| `group_id`     | number 或 string | 当 `message_type` 为 `group` 时必须 | 群号                                      |
| `user_id`      | number 或 string | 当 `message_type` 为 `private` 时必须 | 用户ID                                    |
| `message`      | array    | 是       | 消息内容，为消息段数组                       |

### `message` 数组元素 (`消息段`)

`message` 字段是一个数组，包含一个或多个消息段对象。每个消息段对象至少包含 `type` 和 `data` 字段。

支持的消息段类型如下：

#### `text` (文本消息)
发送纯文本消息。
```json
{
  "type": "text",
  "data": {
    "text": "要发送的文本内容"
  }
}
```
| 参数名 | 类型   | 是否必须 | 说明           |
| ------ | ------ | -------- | -------------- |
| `text` | string | 是       | 文本内容       |

#### `at` (@消息)
@指定用户或全体成员。
```json
{
  "type": "at",
  "data": {
    "qq": "被@的QQ号" // 或 "all" @全体成员
    // "name": "昵称" // 可选，当qq无法获取昵称时作为外显
  }
}
```
| 参数名 | 类型   | 是否必须 | 说明                     |
| ------ | ------ | -------- | ------------------------ |
| `qq`   | number 或 string | 是       | 被@的QQ号，或 `"all"` 代表@全体成员 |
| `name` | string | 否       | 可选，外显名称               |

#### `face` (表情消息)
发送QQ内置表情。
```json
{
  "type": "face",
  "data": {
    "id": 123 // 表情ID
  }
}
```
| 参数名 | 类型   | 是否必须 | 说明       |
| ------ | ------ | -------- | ---------- |
| `id`   | number | 是       | QQ内置表情ID |

#### `image` (图片消息)
发送图片。
```json
{
  "type": "image",
  "data": {
    "file": "图片文件路径或URL或base64"
    // "summary": "[图片]" // 可选，外显
  }
}
```
| 参数名    | 类型   | 是否必须 | 说明                       |
| --------- | ------ | -------- | -------------------------- |
| `file`    | string | 是       | 图片文件路径、URL或base64数据 |
| `summary` | string | 否       | 外显文字，默认为 `[图片]`    |

#### `reply` (回复消息)
回复指定消息。
```json
{
  "type": "reply",
  "data": {
    "id": 123456789 // 被回复的消息ID
  }
}
```
| 参数名 | 类型     | 是否必须 | 说明         |
| ------ | -------- | -------- | ------------ |
| `id`   | number 或 string | 是       | 被回复的消息ID |

#### `json` (JSON消息)
发送JSON卡片消息。
```json
{
  "type": "json",
  "data": {
    "data": "{ ... json content ... }" // JSON字符串
  }
}
```
| 参数名 | 类型   | 是否必须 | 说明               |
| ------ | ------ | -------- | ------------------ |
| `data` | string | 是       | 包含JSON内容的字符串 |

#### `record` (语音消息)
发送语音消息。
```json
{
  "type": "record",
  "data": {
    "file": "语音文件路径或URL或base64"
  }
}
```
| 参数名 | 类型   | 是否必须 | 说明                       |
| ------ | ------ | -------- | -------------------------- |
| `file` | string | 是       | 语音文件路径、URL或base64数据 |

#### `video` (视频消息)
发送视频消息。
```json
{
  "type": "video",
  "data": {
    "file": "视频文件路径或URL或base64"
  }
}
```
| 参数名 | 类型   | 是否必须 | 说明                       |
| ------ | ------ | -------- | -------------------------- |
| `file` | string | 是       | 视频文件路径、URL或base64数据 |

#### `record` (markdown消息)
发送Markdown消息。
```json
{
  "type": "record",
  "data": {
    "content": "## Markdown内容\n- Item 1\n- Item 2"
  }
}
```
| 参数名    | 类型   | 是否必须 | 说明           |
| --------- | ------ | -------- | -------------- |
| `content` | string | 是       | Markdown内容   |

**注意**: 根据 OpenAPI 规范，`语音消息` 和 `markdown消息` 都使用了 `type: "record"`。这在消息段解析时可能导致歧义。请根据实际库的实现方式确定如何区分或使用。

## 响应

成功时返回的数据结构如下：

```json
{
  "status": "ok",
  "retcode": 0, // 或其他成功状态码
  "data": {
    "message_id": 123456789 // 发送成功的消息ID
  },
  "message": "", // 描述信息
  "wording": "", // 用户友好的描述信息
  "echo": null // 可能包含请求中的 echo 字段
}
```

| 参数名       | 类型   | 说明             |
| ------------ | ------ | ---------------- |
| `status`     | string | 状态，`"ok"` 表示成功 |
| `retcode`    | number | 返回码           |
| `data`       | object | 响应数据体       |
| `data.message_id` | number | 发送成功的消息ID |
| `message`    | string | 描述信息         |
| `wording`    | string | 用户友好的描述信息 |
| `echo`       | string | 可能包含请求中的 echo 字段 |

## 示例

### 发送私聊文本消息

```json
{
    "message_type": "private",
    "user_id": "123456789",
    "message": [
        {
            "type": "text",
            "data": {
                "text": "你好，这是一条私聊消息。"
            }
        }
    ]
}
```

### 发送群聊混合消息 (@+文本+图片)

```json
{
    "message_type": "group",
    "group_id": "480972475",
    "message": [
        {
            "type": "at",
            "data": {
                "qq": "123456789"
            }
        },
        {
            "type": "text",
            "data": {
                "text": " 看看这张图片："
            }
        },
        {
            "type": "image",
            "data": {
                "file": "https://example.com/path/to/image.jpg"
            }
        }
    ]
}
```

### 发送群聊回复消息

```json
{
    "message_type": "group",
    "group_id": "480972475",
    "message": [
        {
            "type": "reply",
            "data": {
                "id": 987654321 // 回复消息的ID
            }
        },
        {
            "type": "text",
            "data": {
                "text": "收到！"
            }
        }
    ]
}
```