# 获取消息详情

**Endpoint:** `/get_msg`

**方法:** `POST`

**标签:** 消息相关

**说明:**

该 API 用于通过消息 ID 获取指定消息的详细信息。

**请求体 (Request Body):**

请求体是一个 JSON 对象，包含以下字段:

| 字段名     | 类型         | 必填 | 说明       |
| :--------- | :----------- | :--- | :--------- |
| `message_id` | `number` 或 `string` | 是   | 要获取详情的消息 ID |

**响应 (Response):**

成功响应 (`200 OK`) 返回一个 JSON 对象，包含以下字段：

| 字段名   | 类型   | 必填 | 说明         |
| :------- | :----- | :--- | :----------- |
| `status` | `string` | 是   | 响应状态，固定为 "ok" |
| `retcode`| `number` | 是   | 响应码       |
| `data`   | `object` | 是   | 消息详情数据 |
| `message`| `string` | 是   | 响应消息     |
| `wording`| `string` | 是   | 响应提示     |
| `echo`   | `string` | 是   | Echo 数据    |

**`data` 字段 (消息详情) 结构:**

`data` 字段是一个 JSON 对象，代表消息的详细信息，包含以下字段：

| 字段名         | 类型             | 必填 | 说明                                                                                                      |
| :------------- | :--------------- | :--- | :-------------------------------------------------------------------------------------------------------- |
| `self_id`      | `number`         | 是   | 接收此消息的机器人的 QQ 号                                                                                |
| `user_id`      | `number`         | 是   | 消息发送者的 QQ 号                                                                                        |
| `time`         | `number`         | 是   | 消息发送的时间戳                                                                                          |
| `message_id`   | `number`         | 是   | 消息 ID                                                                                                   |
| `message_seq`  | `number`         | 是   | 消息序列号                                                                                                |
| `real_id`      | `number`         | 是   | 消息的真实 ID                                                                                             |
| `real_seq`     | `string`         | 是   | 消息的真实序列号 (字符串)                                                                                 |
| `message_type` | `string`         | 是   | 消息类型，如 `private` (私聊) 或 `group` (群聊)                                                           |
| `sender`       | `object`         | 是   | 发送者信息                                                                                                |
| `raw_message`  | `string`         | 是   | 消息的原始 CQ 码                                                                                          |
| `font`         | `number`         | 是   | 字体                                                                                                      |
| `sub_type`     | `string`         | 是   | 消息子类型，例如对于群消息可能是 `normal` (普通), `anonymous` (匿名), `notice` (公告) 等                     |
| `message`      | `array<object>`  | 是   | 消息内容，是一个消息段 (Message Segment) 数组。每个消息段是包含 `type` 和 `data` 字段的对象。                 |
| `message_format` | `string`       | 是   | 消息格式，如 `array` (消息段数组)                                                                         |
| `post_type`    | `string`         | 是   | 上报类型，固定为 `message`                                                                                |
| `group_id`     | `number`         | 否   | 群号 (仅在群聊消息中出现)                                                                                 |

**`sender` 字段结构:**

`sender` 字段是一个 JSON 对象，代表发送者的信息，包含以下字段：

| 字段名    | 类型             | 必填 | 说明             |
| :-------- | :--------------- | :--- | :--------------- |
| `user_id` | `number`         | 是   | 发送者 QQ 号     |
| `nickname`| `string`         | 是   | 昵称             |
| `sex`     | `string`         | 否   | 性别 (`male`, `female`, `unknown`) |
| `age`     | `number`         | 否   | 年龄             |
| `card`    | `string`         | 是   | 群名片/备注      |
| `role`    | `string`         | 否   | 角色 (`owner`, `admin`, `member`) |

**`message` 字段 (消息段数组):**

`message` 字段是一个数组，包含构成消息的各个消息段。每个消息段对象至少包含 `type` 和 `data` 字段。`type` 表示消息段类型，`data` 包含该类型的具体数据。

常见消息段类型包括：
-   `text`: 文本消息 (`data` 包含 `text` 字段)
-   `at`: @消息 (`data` 包含 `qq` 和可选的 `name` 字段)
-   `face`: 表情消息 (`data` 包含 `id` 字段)
-   `image`: 图片消息 (`data` 包含 `file` 和可选的 `summary` 字段)
-   `file`: 文件消息 (`data` 包含 `file` 和可选的 `name` 字段)
-   `reply`: 回复消息 (`data` 包含 `id` 字段)
-   `json`: JSON 消息 (`data` 包含 `data` 字段)
-   `record`: 语音消息 (`data` 包含 `file` 字段)
-   `video`: 视频消息 (`data` 包含 `file` 字段)
-   `markdown`: Markdown 消息 (`data` 包含 `content` 字段)
-   `forward`: 合并转发消息 (`data` 包含 `id` 和 `content` 字段，`content` 是一个 `消息详情` 数组)

**示例:**

暂无示例。
