# API Endpoints

## 获取合并转发消息

*   **Endpoint:** `/get_forward_msg`
*   **方法:** `POST`
*   **说明:** 根据合并转发消息的 `message_id` 获取该合并转发消息的详细内容。此接口返回的数据是合并转发消息列表中每一条消息的完整信息。

### 参数

| 参数名     | 类型     | 必填 | 说明                     |
| :--------- | :------- | :--- | :----------------------- |
| `message_id` | `string` | 是   | 合并转发消息的 `message_id` |

### 响应

成功时返回包含合并转发消息详细内容的数据。

```json
{
  "status": "ok",
  "retcode": 0, // 或其他成功状态码
  "data": {
    "message": [ // 合并转发消息内的消息列表，每个元素代表转发列表中的一条消息
      {
        // ... 消息对象的详细属性，参考下方的 "合并转发消息中的子消息对象" 结构说明
      }
      // ... 更多消息项
    ]
  },
  "message": "", // 错误信息 (成功时为空)
  "wording": "", // 友好错误提示 (成功时为空)
  "echo": "client_echo" // 客户端echo回显 (如果请求时携带)
}
```

#### 响应结构说明

*   `status`: `string` - 状态，固定为 "ok"。
*   `retcode`: `number` - 返回码，表示操作结果。
*   `data`: `object` - 响应数据体。
    *   `message`: `array` - 包含合并转发消息中的各个子消息对象。每个元素是转发列表中的一条消息，其结构详见下文的 "合并转发消息中的子消息对象" 说明。
*   `message`: `string` - 错误信息 (成功时为空)。
*   `wording`: `string` - 友好错误提示 (成功时为空)。
*   `echo`: `string`, `nullable` - 客户端echo回显。

#### 合并转发消息中的子消息对象结构 (<a name="forward_message_item"></a>)

`data.message` 数组中的每个元素都代表了合并转发列表中独立的一条消息，其结构如下：

| 属性名         | 类型    | 说明                                                                                                                                |
| :------------- | :------ | :---------------------------------------------------------------------------------------------------------------------------------- |
| `self_id`      | `number` | 机器人QQ号。                                                                                                                        |
| `user_id`      | `number` | 发送该子消息的用户QQ号。                                                                                                              |
| `time`         | `number` | 发送时间戳。                                                                                                                        |
| `message_id`   | `number` | 该子消息在转发内的ID。                                                                                                               |
| `message_seq`  | `number` | 该子消息在转发内的序号。                                                                                                              |
| `real_id`      | `number` | 该子消息的原始真实消息ID (用于回复等)。                                                                                                  |
| `real_seq`     | `string` | 该子消息的原始真实消息序号 (字符串形式)。                                                                                                 |
| `message_type` | `string` | 消息类型 ("group" 或 "private")。                                                                                                     |
| `sender`       | `object` | 发送者信息，结构包含 `user_id`, `nickname`, `sex`, `age`, `card` (群名片，如果存在), `role` (群成员角色，如果存在)。`required: user_id, nickname, card`。 |
| `raw_message`  | `string` | 该子消息的原始消息内容字符串 (可能是CQ码)。                                                                                              |
| `font`         | `number` | 字体。                                                                                                                              |
| `sub_type`     | `string` | 消息子类型 (normal, anonymous, group_self, notice, etc.)。                                                                            |
| `message`      | `array`  | **该子消息的消息段列表。** 这是实际消息内容的组成部分。每个元素代表消息的一个组成部分（如文本、图片、@等）。可能包含以下类型（数组的元素类型 `anyOf`）： |
| `message_format` | `string` | 消息格式 ("array")。                                                                                                                |
| `post_type`    | `string` | 上报类型 ("message")。                                                                                                             |
| `group_id`     | `number` | 群号 (仅当 `message_type` 为 "group" 时存在)。                                                                                        |

#### 消息段类型说明 (在子消息对象的 `message` 数组中)

`message` 数组中的每个元素都是一个消息段对象，其结构取决于 `type` 属性。

1.  **文本消息 (`type: "text"`)**
    *   `data`: `{ "text": "string" }` (必填 `text`)

2.  **艾特消息 (`type: "at"`)**
    *   `data`: `{ "qq": "string" or "number" or "all", "name": "string" }` (必填 `qq`)。`qq` 为 `all` 时表示 @全体成员。

3.  **表情消息 (`type: "face"`)**
    *   `data`: `{ "id": "number" }` (必填 `id`)

4.  **图片消息 (`type: "image"`)**
    *   `data`: `{ "file": "string", "summary": "string" }` (必填 `file`, `summary` 默认为 `[图片]`, 外显文字)。`file` 为图片文件名或URL/base64编码。

5.  **文件消息 (`type: "file"`)**
    *   `data`: `{ "file": "string", "name": "string" }` (必填 `file`, 可选 `name`)。`file` 为文件 ID 或路径。

6.  **回复消息 (`type: "reply"`)**
    *   `data`: `{ "id": "string" or "number" }` (必填 `id`)。`id` 为回复消息的ID。

7.  **JSON消息 (`type: "json"`)**
    *   `data`: `{ "data": "string" }` (必填 `data`)。

8.  **语音消息 (`type: "record"`)** - **注意: schema 中 `type` 为 "record", `data` 中包含 `file`**
    *   `data`: `{ "file": "string" }` (必填 `file`)。

9.  **视频消息 (`type: "video"`)**
    *   `data`: `{ "file": "string" }` (必填 `file`)。

10. **Markdown消息 (`type: "record"`)** - **注意: schema 中 `type` 为 "record", `data` 中包含 `content`**
    *   `data`: `{ "content": "string" }` (必填 `content`)。

11. **嵌套合并转发消息 (`type: "forward"`)**
    *   `data`: `{ "id": "string", "content": [ <a href="#forward_message_item">合并转发消息中的子消息对象</a>, ... ] }` (必填 `id`, `content`)。`content` 数组结构与顶层的 `data.message` 数组结构相同，表示嵌套的转发列表。

### 错误码

参考 [通用返回码说明](/通用返回码说明)

### 编辑日志

*   初次编写文档，基于 OpenAPI schema。