# 获取群成员列表

**路径:** `POST /get_group_member_list`

**概述:** 获取指定群组的成员列表。

**说明:**

此 API 用于获取指定群组的所有成员的详细信息。默认情况下，会使用缓存数据。如果需要获取最新数据，可以设置 `no_cache` 参数。获取到的数据是一个包含群成员详细信息的数组。

**请求参数:**

| 参数名   | 类型         | 必填 | 默认值 | 说明                                        |
| :------- | :----------- | :--- | :----- | :------------------------------------------ |
| group_id | number/string | 是   | 无     | 群号                                        |
| no_cache | boolean      | 否   | false  | 是否不使用缓存，获取实时数据（可能较慢） |

**响应数据:**

成功时返回包含群成员列表的 JSON 对象。

| 字段名      | 类型                 | 说明                                      |
| :---------- | :------------------- | :---------------------------------------- |
| status      | string               | 请求状态，`ok` 表示成功                   |
| retcode     | number               | 返回码                                    |
| data        | array&lt;object&gt; | 群成员列表，每个对象包含一个成员的信息   |
| message     | string               | 错误信息（当 status 不为 `ok` 时）        |
| wording     | string               | 详细错误信息（当 status 不为 `ok` 时）    |
| echo        | string               | 回显字段（如果请求中包含）                |

**`data` 数组中的成员信息 (`群成员信息`) 对象字段说明:**

| 字段名            | 类型    | 说明              |
| :---------------- | :------ | :---------------- |
| group_id          | number  | 群号              |
| user_id           | number  | QQ 号             |
| nickname          | string  | 昵称              |
| card              | string  | 群名片/群昵称      |
| sex               | string  | 性别              |
| age               | number  | 年龄              |
| area              | string  | 地区              |
| level             | number  | 群等级            |
| qq_level          | number  | 账号等级          |
| join_time         | number  | 加群时间戳 (秒)   |
| last_sent_time    | number  | 最后发言时间戳 (秒) |
| title_expire_time | number  | 头衔过期时间戳 (秒) |
| unfriendly        | boolean | 是否不良记录成员   |
| card_changeable   | boolean | 群名片是否可以修改 |
| is_robot          | boolean | 是否机器人        |
| shut_up_timestamp | number  | 禁言到期时间戳 (秒) |
| role              | string  | 成员权限 (owner, admin, member) |
| title             | string  | 专属头衔          |

**示例:**

**请求示例:**

```json
POST /get_group_member_list HTTP/1.1
Content-Type: application/json

{
  "group_id": 123456,
  "no_cache": false,
  "echo": "my_request_id"
}
```

**响应示例:**

```json
{
  "status": "ok",
  "retcode": 0,
  "data": [
    {
      "group_id": 123456,
      "user_id": 10001,
      "nickname": "张三",
      "card": "小张",
      "sex": "male",
      "age": 25,
      "area": "广东",
      "level": 5,
      "qq_level": 60,
      "join_time": 1678886400,
      "last_sent_time": 1678890000,
      "title_expire_time": 0,
      "unfriendly": false,
      "card_changeable": true,
      "is_robot": false,
      "shut_up_timestamp": 0,
      "role": "owner",
      "title": "群主大人"
    },
    {
      "group_id": 123456,
      "user_id": 10002,
      "nickname": "李四",
      "card": "",
      "sex": "female",
      "age": 22,
      "area": "北京",
      "level": 3,
      "qq_level": 50,
      "join_time": 1678887000,
      "last_sent_time": 1678888000,
      "title_expire_time": 0,
      "unfriendly": false,
      "card_changeable": true,
      "is_robot": false,
      "shut_up_timestamp": 0,
      "role": "member",
      "title": ""
    }
    // ...更多成员
  ],
  "message": "",
  "wording": "",
  "echo": "my_request_id"
}
```

**错误码:**

请参考 [go-cqhttp 状态码列表](https://docs.go-cqhttp.org/api/#%E7%8A%B6%E6%80%81%E7%A0%81%E5%88%97%E8%A1%A8) 或相关 Napcat 文档。