# API 名称: 获取语音消息详情

## Endpoint

`POST /get_record`

## 说明

该API用于获取指定语音消息的详细信息，并可选择指定输出格式。这通常用于将收到的语音消息转换为更常见的格式。

## 请求参数

请求体使用 `application/json` 格式。

| 参数名      | 类型     | 必需 | 说明                                                                 | 可选值                                      |
| :---------- | :------- | :--- | :------------------------------------------------------------------- | :------------------------------------------ |
| `file`      | `string` | 否   | 语音文件名或路径（取决于你的Bot的文件处理方式）。**与 `file_id` 二选一提供。** | -                                           |
| `file_id`   | `string` | 否   | 语音文件ID，通常由Bot接收消息时返回。**与 `file` 二选一提供。**        | -                                           |
| `out_format`| `string` | 是   | 希望输出的语音文件格式。                                             | `mp3`, `amr`, `wma`, `m4a`, `spx`, `ogg`, `wav`, `flac` |

*注意：你需要至少提供 `file` 或 `file_id` 中的一个来指定要获取的语音消息。*

## 响应数据

成功响应将返回 `application/json` 格式的数据。

```json
{
  "status": "ok",
  "retcode": 0, // 或其他成功码
  "data": {
    "file": "string", // 本地路径
    "url": "string", // 网络路径
    "file_size": "string", // 文件大小
    "file_name": "string", // 文件名
    "base64": "string" // 文件的Base64编码（如果返回）
  },
  "message": "string", // 提示信息
  "wording": "string", // 提示信息 (可能同 message)
  "echo": "string" // 客户端请求时带上的 echo 字段
}
```

### 响应字段说明 (`data` 对象)

| 字段名    | 类型     | 说明                                     |
| :-------- | :------- | :--------------------------------------- |
| `file`    | `string` | 获取到的语音文件在Bot本地的路径。            |
| `url`     | `string` | 获取到的语音文件的网络URL（如果可用）。      |
| `file_size`| `string` | 语音文件的大小，通常以字节为单位的字符串。     |
| `file_name`| `string` | 语音文件的原始文件名（转换后）。             |
| `base64`  | `string` | 语音文件的Base64编码字符串，方便直接使用。   |

### 响应字段说明 (通用)

| 字段名  | 类型     | 说明                                   |
| :------ | :------- | :------------------------------------- |
| `status`| `string` | 请求状态，通常为 `ok` 表示成功。       |
| `retcode`| `number` | 响应码，`0` 通常表示成功，非 `0` 表示失败。 |
| `message`| `string` | 额外的文字消息，可能包含错误信息。     |
| `wording`| `string` | 额外的文字消息，可能包含错误信息。     |
| `echo`  | `string` | 如果请求中包含 `echo` 字段，则原样返回。 |

## 示例

### 请求示例

```json
{
  "file": "voice_message.silk",
  "out_format": "mp3"
}
```

或者使用 `file_id`:

```json
{
  "file_id": "your_file_id_here",
  "out_format": "wav"
}
```

### 响应示例 (成功)

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "file": "/path/to/bot/data/voice_message.mp3",
    "url": "http://bot_server/voice/voice_message.mp3",
    "file_size": "123456",
    "file_name": "voice_message.mp3",
    "base64": "..." // base64 encoded string
  },
  "message": "成功",
  "wording": "成功",
  "echo": "client_echo_data"
}
```

## 编辑日志

- 初次创建文档。