# API: 发送群合并转发消息

## Endpoint

`POST /send_group_forward_msg`

## 说明

此 API 用于向指定群聊发送合并转发消息。合并转发消息可以包含多条来自不同用户（可伪造）的消息内容，形成一个可展开的消息列表。

## 请求参数

请求体为一个 JSON 对象，包含以下字段：

| 字段名   | 类型           | 必须 | 说明                                                           |
| :------- | :------------- | :--- | :------------------------------------------------------------- |
| `group_id` | `number` 或 `string` | 是   | 目标群号。                                                     |
| `messages` | `array`        | 是   | 合并转发消息节点列表。每个元素代表消息中的一个独立节点（一条伪造的消息）。 |
| `news`     | `array`        | 是   | 附加文本列表。每个元素是一个 `{ "text": "..." }` 对象，文本会显示在合并转发消息的头部或底部附近。 |
| `prompt`   | `string`       | 是   | 外显文字，通常显示在消息头部，如“xxx 等 n 条消息”。                 |
| `summary`  | `string`       | 是   | 底部文字，通常显示在消息底部，如“点击查看详情”。                  |
| `source`   | `string`       | 是   | 消息标题或来源名称，显示在消息头部，如“聊天记录”或群名/用户名。      |

### `messages` 数组元素 (`一级合并转发消息`) 结构说明

`messages` 数组中的每个对象代表合并转发消息中的一个节点，其结构如下：

| 字段名    | 类型    | 必须 | 说明                                         |
| :-------- | :------ | :--- | :------------------------------------------- |
| `type`    | `string` | 是   | 固定为 `"node"`。                          |
| `data`    | `object` | 是   | 节点内容。                                   |

`data` 对象包含以下字段：

| 字段名     | 类型           | 必须 | 说明                                                                                                                            |
| :--------- | :------------- | :--- | :------------------------------------------------------------------------------------------------------------------------------ |
| `user_id`  | `number` 或 `string` | 是   | 节点消息的发送者用户ID，可以伪造。                                                                                              |
| `nickname` | `string`       | 是   | 节点消息的发送者昵称，可以伪造。                                                                                                |\n| `content`  | `array`        | 是   | 节点消息内容列表。由消息段组成，例如文本、图片等。支持的消息段类型包括：`text`, `face`, `image`, `reply`, `json`, `video`, `file`, `markdown`, `forward`, `二级合并转发消息`。其中 `forward` 段可用于嵌套已发送的合并转发消息，`二级合并转发消息` 段可用于创建嵌套的合并转发。 |

### `news` 数组元素结构说明

`news` 数组中的每个对象结构如下：

| 字段名 | 类型    | 必须 | 说明                               |
| :----- | :------ | :--- | :--------------------------------- |
| `text` | `string` | 是   | 需要显示的附加文本内容。           |

## 响应

API 将返回一个 JSON 对象，表示发送操作的结果。

### 状态码 `200` (成功)

| 字段名  | 类型     | 必须 | 说明                   |
| :------ | :------- | :--- | :--------------------- |
| `status`| `string` | 是   | 状态码，`"ok"` 表示成功。 |
| `retcode`| `number` | 是   | 返回码。               |
| `data`  | `object` | 是   | 响应数据。             |
| `message`| `string` | 是   | 消息。                 |
| `wording`| `string` | 是   | 详细说明。             |
| `echo`  | `string` | 是   | Echo 参数（可能为 `null`）。 |

`data` 对象包含以下字段：

| 字段名       | 类型     | 必须 | 说明                               |
| :----------- | :------- | :--- | :--------------------------------- |
| `message_id` | `number` | 是   | 发送成功的合并转发消息的消息ID。   |
| `res_id`     | `string` | 是   | 发送成功的合并转发消息的资源ID。此ID可用于在其他合并转发消息中嵌套引用。 |

## 示例

暂无示例。
