# 发送私聊合并转发消息

**Endpoint:** `POST /send_private_forward_msg`

**描述:** 此API用于向指定用户发送一条私聊合并转发消息。合并转发消息将多条消息组合在一起，以一个消息卡片的形式展示给接收方。

**标签:** 消息相关/发送私聊消息

## 请求体 (Request Body)

请求体是一个JSON对象，包含以下字段：

| 字段名   | 类型   | 是否必须 | 描述                                                                 |
| :------- | :----- | :------- | :------------------------------------------------------------------- |
| `user_id` | number/string | 是       | 接收合并转发消息的用户 QQ 号。                                           |
| `messages` | array  | 是       | 合并转发消息的节点列表。每个节点代表合并转发消息中的一条子消息。 |

### `messages` 数组项 (`node`) 结构

`messages` 数组中的每个项都是一个代表消息节点的JSON对象，其结构如下：

| 字段名   | 类型   | 是否必须 | 描述                                                                 |
| :------- | :----- | :------- | :------------------------------------------------------------------- |
| `type`   | string | 是       | 节点类型，固定为 `"node"`。                                          |
| `data`   | object | 是       | 节点数据，包含子消息的具体信息。                                     |

### `node.data` 结构

`node.data` 是一个JSON对象，包含以下字段：

| 字段名    | 类型          | 是否必须 | 描述                                                                 |
| :-------- | :------------ | :------- | :------------------------------------------------------------------- |
| `nickname` | string        | 是       | 子消息的发送者昵称。                                                 |
| `user_id`  | number/string | 是       | 子消息的发送者 QQ 号。                                               |
| `content`  | array         | 是       | 子消息的内容，是消息段数组。                                         |

### `node.data.content` 数组项 (`消息段`) 结构

`content` 数组是一个消息段数组，每个消息段可以是以下类型之一：

*   **文本消息** (`text`): `{ "type": "text", "data": { "text": "string" } }`
*   **艾特消息** (`at`): `{ "type": "at", "data": { "qq": "number/string ('all')" } }` (可选 `name` 字段)
*   **表情消息** (`face`): `{ "type": "face", "data": { "id": "number" } }`
*   **图片消息** (`image`): `{ "type": "image", "data": { "file": "string", "summary": "string" } }`
*   **回复消息** (`reply`): `{ "type": "reply", "data": { "id": "number/string" } }`
*   **JSON消息** (`json`): `{ "type": "json", "data": { "data": "string" } }`
*   **语音消息** (`record`): `{ "type": "record", "data": { "file": "string" } }`
*   **视频消息** (`video`): `{ "type": "video", "data": { "file": "string" } }`

## 响应 (Response)

### 成功响应 (Status Code: 200)

成功时返回一个JSON对象，包含以下字段：

| 字段名   | 类型   | 描述                                                                 |
| :------- | :----- | :------------------------------------------------------------------- |
| `status` | string | 状态，通常为 `"ok"`。                                                |
| `retcode` | number | 返回码。                                                             |
| `data`   | object | 响应数据。                                                           |
| `message` | string | 消息。                                                               |
| `wording` | string | 附加消息。                                                           |
| `echo`   | string | 可能包含发送请求时携带的 `echo` 字段，nullable。                     |

### `data` 结构

成功响应中的 `data` 字段是一个JSON对象，包含以下字段：

| 字段名      | 类型   | 描述                   |
| :---------- | :----- | :--------------------- |
| `message_id` | number | 发送消息的消息 ID。    |
| `res_id`    | string | 资源 ID（如文件 ID）。 |

## 示例 (Example)

**请求体示例:**

```json
{
  "user_id": 123456789,
  "messages": [
    {
      "type": "node",
      "data": {
        "nickname": "用户A",
        "user_id": 987654321,
        "content": [
          { "type": "text", "data": { "text": "这是用户A发送的第一条消息。" } },
          { "type": "image", "data": { "file": "base64://..." } }
        ]
      }
    },
    {
      "type": "node",
      "data": {
        "nickname": "用户B",
        "user_id": 112233445,
        "content": [
          { "type": "text", "data": { "text": "这是用户B的回复。" } },
          { "type": "reply", "data": { "id": 12345 } }
        ]
      }
    }
  ]
}
```

**响应体示例:**

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 67890,
    "res_id": "some_resource_id"
  },
  "message": "成功",
  "wording": "",
  "echo": "user_defined_string"
}
```