# 获取群历史消息

*   **Endpoint:** `/get_group_msg_history`
*   **方法:** `POST`
*   **标签:** 消息相关
*   **说明:** 获取指定群聊的历史消息列表。

## 请求体 (`application/json`)

| 参数名       | 类型         | 描述                                  | 是否必需 | 默认值 |
| :----------- | :----------- | :------------------------------------ | :------- | :----- |
| `group_id`   | number/string | 群号                                  | 是       | 无     |
| `message_seq` | number/string | 消息序列号，从该序列号开始获取，`0` 为最新 | 否       | `0`    |
| `count`      | number       | 获取消息的数量                        | 否       | `20`   |
| `reverseOrder` | boolean      | 是否倒序（从旧到新），`true` 为倒序      | 否       | `true` |

## 响应体 (`application/json`)

| 参数名   | 类型    | 描述                               |
| :------- | :------ | :--------------------------------- |
| `status` | string  | 状态码，`"ok"` 表示成功。            |
| `retcode` | number  | 返回码                              |
| `message` | string  | 消息                               |
| `wording` | string  | 详细消息                           |
| `echo`   | string/null | 回显数据 (如果请求时带了 echo 字段) |
| `data`   | object  | 包含返回的数据，结构见下表。         |

**`data` 字段说明:**

| 参数名     | 类型    | 描述         |
| :--------- | :------ | :----------- |
| `messages` | array   | 消息详情列表 |

**`messages` 数组元素 (`消息详情`) 说明:**

| 参数名         | 类型         | 描述                                         |
| :------------- | :----------- | :------------------------------------------- |
| `self_id`      | number       | 机器人QQ号                                   |
| `user_id`      | number       | 发送者QQ号                                   |
| `time`         | number       | 发送时间戳                                   |
| `message_id`   | number       | 消息 ID                                      |
| `message_seq`  | number       | 消息序列号                                   |
| `real_id`      | number       | 消息真实 ID (可能是 message_id)              |
| `real_seq`     | string       | 消息真实序列号                               |
| `message_type` | string       | 消息类型 (例如 "group")                      |
| `sender`       | object       | 发送者信息，结构见下表 (`sender`)             |
| `raw_message`  | string       | 原始消息字符串                               |
| `font`         | number       | 字体                                         |
| `sub_type`     | string       | 子类型 (例如 "normal")                       |
| `message`      | array        | 消息段列表，结构见下表 (多种消息段类型)         |
| `message_format` | string       | 消息格式 (例如 "array")                      |
| `post_type`    | string       | 上报类型 (例如 "message")                    |
| `group_id`     | number       | 群号                                         |

**`sender` 字段说明:**

| 参数名     | 类型   | 描述                                    |
| :--------- | :----- | :-------------------------------------- |
| `user_id`  | number | 用户QQ号                                |
| `nickname` | string | 昵称                                    |
| `sex`      | string | 性别 (`"male"`, `"female"`, `"unknown"`) |
| `age`      | number | 年龄                                    |
| `card`     | string | 群名片/昵称                             |
| `role`     | string | 群成员角色 (`"owner"`, `"admin"`, `"member"`) |

**`message` 数组元素 (消息段) 说明:**

`message` 数组中的每个元素都是一个对象，表示消息的一个组成部分（消息段）。每个消息段都有一个 `type` 字段指示其类型，以及一个 `data` 字段包含该类型消息段的具体内容。

| 消息段类型 (`type`) | `data` 字段结构                                  | 描述               |
| :---------------- | :----------------------------------------------- | :----------------- |
| `text`            | `{ "text": string }`                           | 文本内容           |
| `at`              | `{ "qq": number/string, "name"?: string }`      | `@all` 或 QQ号，`name` 是可选的名称 |
| `face`            | `{ "id": number }`                             | 表情 ID            |
| `image`           | `{ "file": string, "summary"?: string }`        | 图片文件名/ID，`summary` 是可选的外显文本 |
| `file`            | `{ "file": string, "name"?: string }`           | 文件文件名/ID，`name` 是可选的文件名 |
| `reply`           | `{ "id": number/string }`                      | 被回复消息的 message_id |
| `json`            | `{ "data": string }`                           | JSON 字符串内容    |
| `record`          | `{ "file": string }`                           | 语音文件名/ID      |
| `video`           | `{ "file": string }`                           | 视频文件名/ID      |
| `markdown`        | `{ "content": string }`                        | Markdown 内容      |
| `forward`         | `{ "id": string, "content"?: array }`           | 合并转发 ID，`content` 可能是嵌套的消息详情列表（通常只包含summary） |
