# OCR 图片识别

## Endpoint

`POST /ocr_image`

## 描述

对提供的图片进行文字识别（OCR）。支持通过网络链接或本地文件路径指定图片。

## 标签

*   个人操作

## 请求

### Request Body

通过 JSON 格式在请求体中指定要识别的图片。

| 参数名 | 类型   | 是否必须 | 描述           | 示例                                                |
| :----- | :----- | :------- | :------------- | :-------------------------------------------------- |
| image  | string | 是       | 图片的网络链接或本地文件路径 (file://...) | `https://i0.hdslb.com/bfs/archive/...` 或 `file://D:/a.jpg` |

**Request Body 示例:**

```json
{
    "image": "https://i0.hdslb.com/bfs/archive/c8fd97a40bf79f03e7b76cbc87236f612caef7b2.png"
}
```

或者使用本地路径：

```json
{
    "image": "file://D:/a.jpg"
}
```

## 响应

### 成功响应 (状态码 200)

返回包含识别结果的 JSON 对象。

| 参数名  | 类型            | 描述                                                                |
| :------ | :-------------- | :------------------------------------------------------------------ |
| status  | string          | 响应状态，成功时为 `ok`                                             |
| retcode | number          | 返回码，通常 0 表示成功                                             |
| data    | array           | 识别结果列表，每个元素代表一行文本                                  |
| message | string          | 响应消息                                                            |
| wording | string          | 响应提示（可能为空）                                                |
| echo    | string, nullable | 回显数据（如果请求中包含 echo 参数）                                |

**`data` 数组元素说明 (每行文本):**

| 参数名  | 类型    | 描述                                          |
| :------ | :------ | :-------------------------------------------- |
| text    | string  | 该行文本总和                                  |
| pt1     | object  | 该行文本框左上角顶点坐标 `{ "x": "", "y": "" }` |
| pt2     | object  | 该行文本框右上角顶点坐标 `{ "x": "", "y": "" }` |
| pt3     | object  | 该行文本框右下角顶点坐标 `{ "x": "", "y": "" }` |
| pt4     | object  | 该行文本框左下角顶点坐标 `{ "x": "", "y": "" }` |
| charBox | array   | 拆分后的字符或词块列表                        |
| score   | string  | 该行文本的置信度评分（可能为空）                |

**`charBox` 数组元素说明 (字符或词块):**

| 参数名  | 类型   | 描述                                         |
| :------ | :----- | :------------------------------------------- |
| charText| string | 该字符或词块的文本                           |
| charBox | object | 该字符或词块的文本框顶点坐标 `{ "pt1": {}, ... }` |

**坐标对象 (`pt1`, `pt2`, `pt3`, `pt4`):**

| 参数名 | 类型   | 描述 |
| :----- | :----- | :--- |
| x      | string | X 坐标 |
| y      | string | Y 坐标 |

**成功响应示例:**

```json
{
    "status": "ok",
    "retcode": 0,
    "data": [
        {
            "text": "nU",
            "pt1": {
                "x": "25.930853",
                "y": "1.711797"
            },
            "pt2": {
                "x": "72.461205",
                "y": "2.745806"
            },
            "pt3": {
                "x": "72.193184",
                "y": "14.806514"
            },
            "pt4": {
                "x": "25.662836",
                "y": "13.772506"
            },
            "charBox": [
                {
                    "charText": "nU",
                    "charBox": {
                        "pt1": {
                            "x": "41.186707",
                            "y": "2.050816"
                        },
                        "pt2": {
                            "x": "56.442558",
                            "y": "2.389835"
                        },
                        "pt3": {
                            "x": "56.182915",
                            "y": "14.073647"
                        },\n                        "pt4": {
                            "x": "40.927063",
                            "y": "13.734628"
                        }
                    }
                }
            ],
            "score": ""
        },
        {
            "text": "yion in",
            "pt1": {
                "x": "40.310081",
                "y": "19.155090"
            },
            "pt2": {
                "x": "92.413017",
                "y": "17.004047"
            },
            "pt3": {
                "x": "93.224297",
                "y": "36.654957"
            },
            "pt4": {
                "x": "41.121365",
                "y": "38.806000"
            },
            "charBox": [
                {
                    "charText": "yion",
                    "charBox": {
                        "pt1": {
                            "x": "40.310081",
                            "y": "19.155090"
                        },
                        "pt2": {
                            "x": "66.660988",
                            "y": "18.067207"
                        },
                        "pt3": {
                            "x": "67.446922",
                            "y": "37.104027"
                        },
                        "pt4": {
                            "x": "41.096012",
                            "y": "38.191910"
                        }
                    }
                },
                {
                    "charText": " ",
                    "charBox": {
                        "pt1": {
                            "x": "66.660988",
                            "y": "18.067207"
                        },
                        "pt2": {
                            "x": "73.847603",
                            "y": "17.770512"
                        },
                        "pt3": {
                            "x": "74.633530",
                            "y": "36.807331"
                        },
                        "pt4": {
                            "x": "67.446922",
                            "y": "37.104027"
                        }
                    }
                },
                {
                    "charText": "in",
                    "charBox": {
                        "pt1": {
                            "x": "73.847603",
                            "y": "17.770512"
                        },
                        "pt2": {
                            "x": "85.825287",
                            "y": "17.276018"
                        },
                        "pt3": {
                            "x": "86.611214",
                            "y": "36.312836"
                        },\n                        "pt4": {
                            "x": "74.633530",
                            "y": "36.807331"
                        }
                    }
                }
            ],
            "score": ""
        },
        {
            "text": "mlHttp.",
            "pt1": {
                "x": "6.956338",
                "y": "61.610126"
            },
            "pt2": {
                "x": "72.331848",
                "y": "65.844292"
            },
            "pt3": {
                "x": "71.104248",
                "y": "84.798470"
            },
            "pt4": {
                "x": "5.728738",
                "y": "80.564301"
            },
            "charBox": [
                {
                    "charText": "mlHttp",
                    "charBox": {
                        "pt1": {
                            "x": "9.230268",
                            "y": "61.757401"
                        },
                        "pt2": {
                            "x": "61.530674",
                            "y": "65.144737"
                        },
                        "pt3": {
                            "x": "60.341438",
                            "y": "83.506592"
                        },
                        "pt4": {
                            "x": "8.041031",
                            "y": "80.119255"
                        }
                    }
                },
                {
                    "charText": ".",
                    "charBox": {
                        "pt1": {
                            "x": "63.804607",
                            "y": "65.292007"
                        },
                        "pt2": {
                            "x": "70.626396",
                            "y": "65.733833"
                        },
                        "pt3": {
                            "x": "69.437164",
                            "y": "84.095695"
                        },
                        "pt4": {
                            "x": "62.615368",
                            "y": "83.653870"
                        }
                    }
                }
            ],
            "score": ""
        }
    ],
    "message": "",
    "wording": "",
    "echo": null
}
```

## 错误处理

当发生错误时（例如图片无法访问、识别失败等），`status` 可能不是 `ok`，`retcode` 可能为非 0 值，并且 `message` 会包含错误详情。
