# API Endpoint: `/.ocr_image`

## 概述

本API用于识别图片中的文字内容（OCR）。

## Endpoint 详情

*   **路径:** `/.ocr_image`
*   **方法:** `POST`
*   **标签:** `个人操作`
*   **摘要:** 图片识别功能，提取图片中的文字信息。

## 请求体 (Request Body)

通过JSON格式在请求体中发送图片信息。

*   **Content-Type:** `application/json`

*   **请求参数:**

    | 参数名  | 类型   | 必填 | 说明                                                                 |
    | :------ | :----- | :--- | :------------------------------------------------------------------- |
    | `image` | `string` | 是   | 需要识别的图片路径。可以是网络图片的URL或本地文件路径（格式如 `file://D:/a.jpg`）。 |

*   **请求示例:**

```json
{
    "image": "https://assets.cdn.ifixit.com/static/images/home/search-hero-backgrounds/car_tire-2180.avif"
}
```

或使用本地路径：

```json
{
    "image": "file://D:/a.jpg"
}
```

## 响应 (Response)

成功时返回图片中识别出的文字及其位置信息。

*   **状态码:** `200 OK`
*   **说明:** 图片识别成功。

*   **响应体结构:**

```json
{
    "status": "string", // 状态，固定为 "ok"
    "retcode": "number", // 返回码
    "data": [ // 识别结果列表，每个元素代表一行文本
        {
            "text": "string", // 该行文本的总和内容
            "pt1": { // 文本行的左上角顶点坐标
                "x": "string",
                "y": "string"
            },
            "pt2": { // 文本行的右上角顶点坐标
                "x": "string",
                "y": "string"
            },
            "pt3": { // 文本行的右下角顶点坐标
                "x": "string",
                "y": "string"
            },
            "pt4": { // 文本行的左下角顶点坐标
                "x": "string",
                "y": "string"
            },
            "charBox": [ // 组成该行的字符级别信息列表
                {
                    "charText": "string", // 单个字符或词语的文本
                    "charBox": { // 单个字符或词语的包围框坐标
                        "pt1": { "x": "string", "y": "string" },
                        "pt2": { "x": "string", "y": "string" },
                        "pt3": { "x": "string", "y": "string" },
                        "pt4": { "x": "string", "y": "string" }
                    }
                }
                // ... 更多字符框
            ],
            "score": "string" // 识别置信度分数
        }
        // ... 更多识别出的行
    ],
    "message": "string", // 消息
    "wording": "string", // 附加说明
    "echo": "string" // 可能包含的echo信息，可为null
}
```

*   **响应示例:**

```json
{
    "status": "ok",
    "retcode": 0,
    "data": [
        {
            "text": "nU",
            "pt1": {
                "x": "25.930853",
                "y": "1.711797"
            },
            "pt2": {
                "x": "72.461205",
                "y": "2.745806"
            },
            "pt3": {
                "x": "72.193184",
                "y": "14.806514"
            },
            "pt4": {
                "x": "25.662836",
                "y": "13.772506"
            },
            "charBox": [
                {
                    "charText": "nU",
                    "charBox": {
                        "pt1": {
                            "x": "41.186707",
                            "y": "2.050816"
                        },
                        "pt2": {
                            "x": "56.442558",
                            "y": "2.389835"
                        },
                        "pt3": {
                            "x": "56.182915",
                            "y": "14.073647"
                        },
                        "pt4": {
                            "x": "40.927063",
                            "y": "13.734628"
                        }
                    }
                }
            ],
            "score": ""
        },
        {
            "text": "yion in",
            "pt1": {
                "x": "40.310081",
                "y": "19.155090"
            },
            "pt2": {
                "x": "92.413017",
                "y": "17.004047"
            },
            "pt3": {
                "x": "93.224297",
                "y": "36.654957"
            },
            "pt4": {
                "x": "41.121365",
                "y": "38.806000"
            },
            "charBox": [
                {
                    "charText": "yion",
                    "charBox": {
                        "pt1": {
                            "x": "40.310081",
                            "y": "19.155090"
                        },
                        "pt2": {
                            "x": "66.660988",
                            "y": "18.067207"
                        },
                        "pt3": {
                            "x": "67.446922",
                            "y": "37.104027"
                        },\n                        "pt4": {
                            "x": "41.096012",
                            "y": "38.191910"
                        }
                    }
                },
                {
                    "charText": " ",
                    "charBox": {
                        "pt1": {
                            "x": "66.660988",
                            "y": "18.067207"
                        },
                        "pt2": {
                            "x": "73.847603",
                            "y": "17.770512"
                        },
                        "pt3": {
                            "x": "74.633530",
                            "y": "36.807331"
                        },
                        "pt4": {
                            "x": "67.446922",
                            "y": "37.104027"
                        }
                    }
                },
                {
                    "charText": "in",
                    "charBox": {
                        "pt1": {
                            "x": "73.847603",
                            "y": "17.770512"
                        },
                        "pt2": {
                            "x": "85.825287",
                            "y": "17.276018"
                        },
                        "pt3": {
                            "x": "86.611214",
                            "y": "36.312836"
                        },
                        "pt4": {
                            "x": "74.633530",
                            "y": "36.807331"
                        }
                    }
                }
            ],
            "score": ""
        },
        {
            "text": "mlHttp.",
            "pt1": {
                "x": "6.956338",
                "y": "61.610126"
            },
            "pt2": {
                "x": "72.331848",
                "y": "65.844292"
            },
            "pt3": {
                "x": "71.104248",
                "y": "84.798470"
            },
            "pt4": {
                "x": "5.728738",
                "y": "80.564301"
            },
            "charBox": [
                {
                    "charText": "mlHttp",
                    "charBox": {
                        "pt1": {
                            "x": "9.230268",
                            "y": "61.757401"
                        },
                        "pt2": {
                            "x": "61.530674",
                            "y": "65.144737"
                        },
                        "pt3": {
                            "x": "60.341438",
                            "y": "83.506592"
                        },
                        "pt4": {
                            "x": "8.041031",
                            "y": "80.119255"
                        }
                    }
                },
                {
                    "charText": ".",
                    "charBox": {
                        "pt1": {
                            "x": "63.804607",
                            "y": "65.292007"
                        },
                        "pt2": {
                            "x": "70.626396",
                            "y": "65.733833"
                        },
                        "pt3": {
                            "x": "69.437164",
                            "y": "84.095695"
                        },
                        "pt4": {
                            "x": "62.615368",
                            "y": "83.653870"
                        }
                    }
                }
            ],
            "score": ""
        }
    ],
    "message": "",
    "wording": "",
    "echo": null
}
```