## API: 获取群精华消息

### Endpoint
`/get_essence_msg_list`

### 方法
`POST`

### 描述
获取指定群聊的精华消息列表。

### 请求参数

请求体 (`application/json`):

| 参数名   | 类型             | 必填 | 描述     |
| -------- | ---------------- | ---- | -------- |
| group_id | number 或 string | 是   | 群号     |

**示例请求体:**

```json
{
  "group_id": 1012451981
}
```

### 响应

**成功响应 (Status: 200, Content-Type: application/json):**

标准响应体包含 `status`, `retcode`, `message`, `wording`, `echo` 字段，其中 `data` 字段为精华消息列表。

`data` 字段结构 (`array<object>`):

| 字段名        | 类型    | 描述         |
| ------------- | ------- | ------------ |
| msg_seq       | number  | 消息 seq     |
| msg_random    | number  | 消息 random  |
| sender_id     | number  | 发送人账号   |
| sender_nick   | string  | 发送人昵称   |
| operator_id   | number  | 设精人账号   |
| operator_nick | string  | 设精人昵称   |
| message_id    | number  | 消息 ID      |
| operator_time | number  | 设精时间 (秒)|
| content       | array   | 消息内容     |

`content` 字段是消息段的数组，可能包含以下类型：

*   **文本消息**: `{ "type": "text", "data": { "text": "string" } }`
*   **图片消息**: `{ "type": "image", "data": { "url": "string" } }`
    *   注意：图片消息在精华消息列表中，data字段可能只包含`url`。

**示例成功响应:**

```json
{
  "status": "ok",
  "retcode": 0,
  "data": [
    {
      "msg_seq": 12345,
      "msg_random": 67890,
      "sender_id": 123456789,
      "sender_nick": "发送者昵称",
      "operator_id": 987654321,
      "operator_nick": "设精者昵称",
      "message_id": 54321,
      "operator_time": 1678886400,
      "content": [
        {
          "type": "text",
          "data": {
            "text": "这是一条精华文本消息"
          }
        }
      ]
    },
    {
      "msg_seq": 12346,
      "msg_random": 67891,
      "sender_id": 123456789,
      "sender_nick": "发送者昵称",
      "operator_id": 987654321,
      "operator_nick": "设精者昵称",
      "message_id": 54322,
      "operator_time": 1678886500,
      "content": [
        {
          "type": "text",
          "data": {
            "text": "精华消息，包含图片："
          }
        },
        {
          "type": "image",
          "data": {
            "url": "http://example.com/image.jpg"
          }
        }
      ]
    }
  ],
  "message": "",
  "wording": "",
  "echo": null
}
```

### 错误响应

根据 `retcode` 和 `status` 判断。

**示例错误响应:**

```json
{
  "status": "failed",
  "retcode": 100,
  "data": {},
  "message": "Invalid group_id",
  "wording": "群号无效",
  "echo": null
}
```

### 注意事项

*   `operator_time` 是设为精华的时间戳，单位为秒。
*   `content` 字段的消息段结构与发送消息时类似，但图片段在获取时可能只包含 `url` 字段。
