# API文档：获取群根目录文件列表

## Endpoint

`POST /get_group_root_files`

## 概述

该API用于获取指定群组根目录下的文件和文件夹列表。

## 请求参数

请求体 (Content-Type: application/json) 包含以下参数：

| 参数名     | 类型         | 必填 | 默认值 | 描述                               |
| :--------- | :----------- | :--- | :----- | :--------------------------------- |
| `group_id` | `number` 或 `string` | 是   | 无     | 群号                               |
| `file_count`| `number`    | 否   | 50     | 可选，限制返回的文件数量           |

## 响应数据

成功响应返回JSON对象，其`data`字段包含根目录下的文件和文件夹列表：

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "files": [
      { /* 群文件信息 */ }
    ],
    "folders": [
      { /* 群文件夹信息 */ }
    ]
  },
  "message": "",
  "wording": "",
  "echo": "" // 可选，对应请求中的echo字段
}
```

`data`字段的详细说明：

| 字段名    | 类型      | 描述         |
| :-------- | :-------- | :----------- |
| `files`   | `array`   | 文件列表     |
| `folders` | `array`   | 文件夹列表   |

### 群文件信息 (`files` 数组中的元素)

`files` 数组中的每个元素是一个对象，代表一个群文件，包含以下字段：

| 字段名          | 类型     | 描述         |
| :-------------- | :------- | :----------- |
| `group_id`      | `number` | 群号         |
| `file_id`       | `string` | 文件ID       |
| `file_name`     | `string` | 文件名       |
| `busid`         | `number` | 业务ID       |
| `size`          | `number` | 文件大小 (字节)|
| `file_size`     | `number` | 文件大小 (字节)，与 `size` 相同 |
| `upload_time`   | `number` | 上传时间 (Unix 时间戳) |
| `dead_time`     | `number` | 过期时间 (Unix 时间戳) |
| `modify_time`   | `number` | 最后修改时间 (Unix 时间戳) |
| `download_times`| `number` | 下载次数     |
| `uploader`      | `number` | 上传者账号   |
| `uploader_name` | `string` | 上传者昵称   |

### 群文件夹信息 (`folders` 数组中的元素)

`folders` 数组中的每个元素是一个对象，代表一个群文件夹，包含以下字段：

| 字段名           | 类型     | 描述       |
| :--------------- | :------- | :--------- |
| `group_id`       | `number` | 群号       |
| `folder_id`      | `string` | 文件夹ID   |
| `folder`         | `string` | 文件夹名称，与 `folder_name` 相同 |
| `folder_name`    | `string` | 文件夹名称 |
| `create_time`    | `number` | 创建时间 (Unix 时间戳) |
| `creator`        | `number` | 创建人账号 |
| `creator_name`   | `string` | 创建人昵称 |
| `total_file_count`| `number` | 文件夹内文件数量 |

## 示例

**请求:**

```json
{
  "group_id": 123456789,
  "file_count": 100
}
```

**响应:**

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "files": [
      {
        "group_id": 123456789,
        "file_id": "your_file_id_1",
        "file_name": "document.pdf",
        "busid": 102,
        "size": 123456,
        "file_size": 123456,
        "upload_time": 1678886400,
        "dead_time": 0,
        "modify_time": 1678886400,
        "download_times": 5,
        "uploader": 10001,
        "uploader_name": "Alice"
      }
      // ... 其他文件
    ],
    "folders": [
      {
        "group_id": 123456789,
        "folder_id": "your_folder_id_1",
        "folder": "Images",
        "folder_name": "Images",
        "create_time": 1678800000,
        "creator": 10002,
        "creator_name": "Bob",
        "total_file_count": 15
      }
      // ... 其他文件夹
    ]
  },
  "message": "",
  "wording": "",
  "echo": "" 
}
```