# POST /download_file

## 下载文件到缓存目录

### 概述

此API用于将指定URL链接的文件或Base64编码的文件内容下载并保存到Napcat的缓存目录中。成功后，将返回下载后的文件在缓存目录中的路径，通常用于后续的文件操作或发送。

### 请求信息

*   **方法:** `POST`
*   **路径:** `/download_file`
*   **标签:** 文件相关

### 请求参数 (Request Body)

请求体应为 `application/json` 格式，包含以下字段：

| 字段名   | 类型                 | 是否必需 | 说明                                                     |
| :------- | :------------------- | :------- | :------------------------------------------------------- |
| `url`    | `string`             | 否       | 文件下载地址。与 `base64` 参数二选一。                      |
| `base64` | `string`             | 否       | 文件的Base64编码字符串。与 `url` 参数二选一。                |
| `name`   | `string`             | 否       | 自定义保存到缓存目录的文件名称。                           |
| `headers`| `string` 或 `array` | 否       | 下载文件时使用的HTTP请求头（仅在使用 `url` 下载时有效）。|

**注意:** `url` 和 `base64` 必须提供其中一个。

### 响应

#### 状态码: `200 OK`

表示请求成功，文件已成功下载并保存。

**响应体 (JSON):**

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "file": "string"
  },
  "message": "",
  "wording": "",
  "echo": null
}
```

| 字段名    | 类型             | 说明                 |
| :-------- | :--------------- | :------------------- |
| `status`  | `string`         | 状态，`ok` 表示成功。|
| `retcode` | `number`         | 返回码。             |
| `data`    | `object`         | 响应数据对象。       |
| ↳ `file`  | `string`         | 下载后的文件路径。   |
| `message` | `string`         | 响应消息。           |
| `wording` | `string`         | 响应文本。           |
| `echo`    | `string` or `null` | Echo字段。           |

### 示例

#### 请求示例 (通过URL下载):

```json
POST /download_file
Content-Type: application/json

{
  "url": "https://example.com/some_image.jpg",
  "name": "my_custom_image.jpg",
  "headers": "User-Agent: MyApp"
}
```

#### 请求示例 (通过Base64下载):

```json
POST /download_file
Content-Type: application/json

{
  "base64": "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mNkYAAAAAYAAjCB0C8AAAAASUVORK5CYII=",
  "name": "transparent_pixel.png"
}
```

#### 响应示例 (成功):

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "file": "path/to/napcat/cache/files/my_custom_image.jpg"
  },
  "message": "success",
  "wording": "文件下载成功",
  "echo": null
}
```