# API: 获取文件信息

**Endpoint:** `/get_file`

**方法:** `POST`

**标签:** 文件相关

**概述:**

该API用于根据文件ID或文件名获取文件的详细信息，包括路径/链接、大小、文件名以及Base64编码。

**请求体 (Request Body):**

发送一个JSON对象作为请求体，必须提供 `file_id` 或 `file` 中的任意一个。

```json
{
  "file_id": "string", // 文件ID，与 file 二选一
  "file": "string"     // 文件名，与 file_id 二选一
}
```

| 参数名  | 类型   | 描述     | 是否必需 | 备注       |
| :------ | :----- | :------- | :------- | :--------- |
| file_id | string | 文件ID   | 二选一   | 与 `file` 选择其一 |
| file    | string | 文件名   | 二选一   | 与 `file_id` 选择其一 |

**响应 (Response):**

成功时返回状态码 `200`，响应体为一个JSON对象，包含文件的详细信息。

**成功响应体 (Status: 200):**

```json
{
  "status": "ok",
  "retcode": 0, // 或其他成功状态码
  "data": {
    "file": "string",     // 文件在本地的路径或可访问的链接
    "url": "string",      // 文件的可访问链接 (可能与 file 相同)
    "file_size": "string",// 文件大小
    "file_name": "string",// 文件名
    "base64": "string"    // 文件的 Base64 编码
  },
  "message": "string", // 描述信息
  "wording": "string", // 描述信息
  "echo": "string"     // 可能包含请求时的 echo 字段
}
```

| 参数名    | 类型   | 描述                 | 备注                                   |
| :-------- | :----- | :------------------- | :------------------------------------- |
| status    | string | 状态，成功时为 `ok`  |                                        |
| retcode   | number | 返回码               |                                        |
| data      | object | 文件详细信息         |                                        |
| └ file    | string | 文件路径或链接       | 必需                                   |
| └ url     | string | 文件路径或链接       | 必需                                   |
| └ file_size| string | 文件大小             | 必需                                   |
| └ file_name| string | 文件名               | 必需                                   |
| └ base64  | string | Base64 编码          | 必需                                   |
| message   | string | 描述信息             |                                        |
| wording   | string | 描述信息             |                                        |
| echo      | string | 请求时携带的 echo 字段 | 可选，如果请求时包含则响应时返回相同值 |

**错误响应:**

根据实际情况可能会返回不同的 `retcode` 和 `status` (非 `ok`)，以及相应的 `message` 和 `wording` 来指示错误原因（例如，文件未找到）。具体错误码请参考NapcatAPI的通用错误处理说明。
