## API: 获取最近消息列表

**Endpoint:** `/get_recent_contact`

**方法:** `POST`

**标签:** 账号相关

**简介:** 获取最近会话列表及其最新消息。

**说明:** 获取的最新消息是每个会话最新的消息。

#### 请求参数

请求体是一个 JSON 对象，包含以下属性：

| 字段名 | 类型   | 是否必需 | 描述     | 示例值 |
| :----- | :----- | :------- | :------- | :----- |
| count  | number | 否       | 会话数量 | 10     |

#### 响应数据

响应是一个 JSON 对象，通常包含以下字段：

| 字段名  | 类型    | 描述                               | 可能的值     |
| :------ | :------ | :--------------------------------- | :----------- |
| status  | string  | 响应状态                           | `ok`, `failed` |
| retcode | number  | 返回码                             |              |
| data    | array   | 包含最近会话信息的数组             |              |
| message | string  | 响应消息，通常在失败时包含错误信息 |              |
| wording | string  | 响应提示                           |              |
| echo    | string  | 用户在请求中指定的 echo 原样返回   |              |

**`data` 数组中的每个对象代表一个会话，包含以下字段：**

| 字段名       | 类型   | 是否必需 | 描述                                    |
| :----------- | :----- | :------- | :-------------------------------------- |
| lastestMsg   | object | 否       | 最新消息内容 (具体结构参考 `消息详情`)
| peerUin      | string | 是       | 对方账号 (QQ号或群号)                   |
| remark       | string | 是       | 备注或群备注                            |
| msgTime      | string | 是       | 消息时间戳                              |
| chatType     | number | 是       | 会话类型 (如 1 私聊, 2 群聊)            |
| msgId        | string | 是       | 消息ID                                  |
| sendNickName | string | 是       | 最新消息发送人的昵称                    |
| sendMemberName | string | 是       | 最新消息发送人在群内的昵称 (如果是群聊) |
| peerName     | string | 是       | 对方昵称 (好友昵称或群名称)             |

**`lastestMsg` (消息详情) 结构说明:**

`lastestMsg` 是一个嵌套的对象，其结构与 `消息详情` 类型基本一致，但部分字段如 `message_id`, `message_seq`, `real_id` 在此接口中可能被省略或不返回。

其中 `message` 字段是一个数组，包含消息段落信息。数组中的每个元素都是一个对象，表示消息的不同组成部分，可能包含以下类型：

*   `文本消息` (`type: 'text'`) - 文本内容
*   `艾特消息` (`type: 'at'`) - @用户或@全体成员
*   `表情消息` (`type: 'face'`) - QQ自带表情
*   `图片消息` (`type: 'image'`) - 图片
*   `文件消息` (`type: 'file'`) - 文件
*   `回复消息` (`type: 'reply'`) - 回复指定消息
*   `JSON消息` (`type: 'json'`) - JSON格式消息
*   `语音消息` (`type: 'record'`) - 语音
*   `视频消息` (`type: 'video'`) - 视频
*   `markdown消息` (`type: 'record'`) - Markdown格式消息
*   `消息forward` (`type: 'forward'`) - 合并转发消息

具体的消息段结构请参考各自的消息类型定义。

`sender` 字段包含发送人的信息，具体结构参考 `sender` 类型定义。

#### 成功响应示例

```json
{
  "status": "ok",
  "retcode": 0,
  "data": [
    {
      "lastestMsg": {
        ...
        "message": [
          {
            "type": "text",
            "data": {
              "text": "你好"
            }
          }
        ],
        ...
      },
      "peerUin": "123456789",
      "remark": "",
      "msgTime": "1678886400",
      "chatType": 1,
      "msgId": "ABCDEFG",
      "sendNickName": "发送者昵称",
      "sendMemberName": "",
      "peerName": "好友昵称"
    },
    {
      "lastestMsg": {
        ...
        "message": [
           {
            "type": "at",
            "data": {
              "qq": "12345",
              "name": "成员昵称"
            }
          },
          {
            "type": "text",
            "data": {
              "text": " 在吗?"
            }
          }
        ],
        ...
      },
      "peerUin": "987654321",
      "remark": "测试群",
      "msgTime": "1678886300",
      "chatType": 2,
      "msgId": "HIJKLMN",
      "sendNickName": "发送者昵称",
      "sendMemberName": "群成员昵称",
      "peerName": "群名称"
    }
  ],
  "message": "Success",
  "wording": "",
  "echo": null
}
```

**注意:** `lastestMsg` 内部结构可能比较复杂，详情请参考 `消息详情` schema。