## /get_profile_like - 获取点赞列表

### POST /get_profile_like

该接口用于获取当前登录用户或指定用户收到的点赞（vote）和互赞（favorite）信息列表。这些信息包括点赞/互赞的总次数、最新动态以及具体的用户列表。

### 请求参数

| 参数名   | 类型          | 必需 | 默认值 | 说明                     |
| :------- | :------------ | :--- | :----- | :----------------------- |
| `user_id` | `number` 或 `string` | 否   | 无     | 指定用户ID，不填则获取当前登录用户的点赞列表 |
| `start`  | `number`      | 否   | 0      | 分页起始位置，从0开始计 |
| `count`  | `number`      | 否   | 10     | 每页数量                 |

### 响应数据

接口成功时返回如下数据结构：

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "uid": "string",
    "time": number,
    "favoriteInfo": {
      "total_count": number,
      "last_time": number,
      "today_count": number,
      "userInfos": [
        {
          "uid": "string",
          "src": number,
          "latestTime": number,
          "count": number,
          "giftCount": number,
          "customId": number,
          "lastCharged": number,
          "bAvailableCnt": number,
          "bTodayVotedCnt": number,
          "nick": "string",
          "gender": number,
          "age": number,
          "isFriend": boolean,
          "isvip": boolean,
          "isSvip": boolean,
          "uin": number
        }
        // ... 其他点赞信息对象
      ]
    },
    "voteInfo": {
      "total_count": number,
      "new_count": number,
      "new_nearby_count": number,
      "last_visit_time": number,
      "userInfos": [
        {
          "uid": "string",
          "src": number,
          "latestTime": number,
          "count": number,
          "giftCount": number,
          "customId": number,
          "lastCharged": number,
          "bAvailableCnt": number,
          "bTodayVotedCnt": number,
          "nick": "string",
          "gender": number,
          "age": number,
          "isFriend": boolean,
          "isvip": boolean,
          "isSvip": boolean,
          "uin": number
        }
        // ... 其他点赞信息对象
      ]
    }
  },
  "message": "string",
  "wording": "string",
  "echo": "string" | null
}
```

**字段说明:**

*   `status`: 请求状态，`ok` 表示成功。
*   `retcode`: 返回码。
*   `data`: 响应数据本体。
    *   `uid`: string，当前用户的UID。
    *   `time`: number，时间戳(?)。
    *   `favoriteInfo`: object，互赞信息。
        *   `total_count`: number，总互赞次数。
        *   `last_time`: number，最后互赞时间（非时间戳）。
        *   `today_count`: number，今日互赞次数或上次统计次数。
        *   `userInfos`: array，互赞用户列表，每个元素是一个 `点赞信息` 对象。
    *   `voteInfo`: object，点赞信息。
        *   `total_count`: number，总点赞次数。
        *   `new_count`: number，新的点赞次数。
        *   `new_nearby_count`: number，新的附近的人的点赞次数。
        *   `last_visit_time`: number，最后访问时间。
        *   `userInfos`: array，点赞用户列表，每个元素是一个 `点赞信息` 对象。
*   `message`: 响应消息。
*   `wording`: 响应文案。
*   `echo`: 透传的 echo 字段，可能为空。

**点赞信息 (userInfos 数组中的元素) 字段说明:**

*   `uid`: string，用户的UID。
*   `src`: number，来源标识。
*   `latestTime`: number，最新互动时间。
*   `count`: number，互动次数（如点赞次数）。
*   `giftCount`: number，礼物次数。
*   `customId`: number。
*   `lastCharged`: number。
*   `bAvailableCnt`: number。
*   `bTodayVotedCnt`: number，今日是否点赞过（?）。
*   `nick`: string，用户昵称。
*   `gender`: number，性别（通常 0:未知, 1:男, 2:女，但具体含义以实际为准）。
*   `age`: number，年龄。
*   `isFriend`: boolean，是否是好友。
*   `isvip`: boolean，是否是QQ会员。
*   `isSvip`: boolean，是否是超级会员。
*   `uin`: number，用户的QQ号。
