# 获取群禁言列表

## Endpoint

`POST /get_group_shut_list`

## 简介

获取指定群的禁言成员列表。

## 请求

### 请求体 (Request Body)

请求体使用 `application/json` 格式。

| 参数名   | 类型                | 必填 | 描述     |
| :------- | :------------------ | :--- | :------- |
| group_id | `number` 或 `string` | 是   | 群号     |

### 请求示例

```json
{
  "group_id": 123456789
}
```

## 响应

### 状态码

`200 OK`

### 响应体 (Response Body)

响应体使用 `application/json` 格式，表示一个标准API结果对象，其中 `data` 字段是一个数组，包含群中被禁言成员的详细信息。

| 参数名  | 类型    | 描述                                   |
| :------ | :------ | :------------------------------------- |
| status  | `string` | 状态，`ok` 表示成功                   |
| retcode | `number` | 返回码                                 |
| data    | `array`  | 禁言成员列表数组，每个元素包含成员详细信息 |
| message | `string` | 消息                                   |
| wording | `string` | 提示信息                               |
| echo    | `string` | 回显请求中的 `echo` 字段 (如果存在)    |

#### `data` 数组元素说明

`data` 数组的每个元素都是一个对象，包含以下字段：

| 参数名            | 类型     | 描述         |
| :---------------- | :------- | :----------- |
| uid               | `string` | 用户 UID     |
| qid               | `string` | 用户 QID     |
| uin               | `string` | 用户 UIN     |
| nick              | `string` | 昵称         |
| remark            | `string` | 备注名       |
| cardType          | `number` | 名片类型     |
| cardName          | `string` | 名片名称     |
| role              | `number` | 群内角色 (0: 成员, 1: 管理员, 2: 群主) |
| avatarPath        | `string` | 头像路径     |
| shutUpTime        | `number` | 解禁时间 (Unix timestamp) |
| isDelete          | `boolean`| 是否已删除   |
| isSpecialConcerned | `boolean`| 是否特别关注 |
| isSpecialShield   | `boolean`| 是否特别屏蔽 |
| isRobot           | `boolean`| 是否机器人   |
| groupHonor        | `object` | 群荣誉信息 (目前为空) |
| memberRealLevel   | `number` | 群聊等级     |
| memberLevel       | `number` | 成员等级     |
| globalGroupLevel  | `number` | 全局群等级   |
| globalGroupPoint  | `number` | 全局群积分   |
| memberTitleId     | `number` | 成员头衔 ID  |
| memberSpecialTitle| `string` | 成员特殊头衔 |
| specialTitleExpireTime| `string`| 特殊头衔过期时间 |
| userShowFlag      | `number` | 用户展示标志 |
| userShowFlagNew   | `number` | 新用户展示标志 |
| richFlag          | `number` | 富豪标志     |
| mssVipType        | `number` | MSS VIP 类型 |
| bigClubLevel      | `number` | 大会员等级   |
| bigClubFlag       | `number` | 大会员标志   |
| autoRemark        | `string` | 自动备注     |
| creditLevel       | `number` | 信用等级     |
| joinTime          | `number` | 入群时间 (Unix timestamp) |
| lastSpeakTime     | `number` | 最后发言时间 (Unix timestamp) |
| memberFlag        | `number` | 成员标志     |
| memberFlagExt     | `number` | 成员标志扩展 |
| memberMobileFlag  | `number` | 成员手机标志 |
| memberFlagExt2    | `number` | 成员标志扩展2 |
| isSpecialShielded | `boolean`| 是否被特别屏蔽 |
| cardNameId        | `number` | 名片名称 ID  |

### 响应示例

```json
{
  "status": "ok",
  "retcode": 0,
  "data": [
    {
      "uid": "some_uid_1",
      "qid": "some_qid_1",
      "uin": "123456789",
      "nick": "成员昵称1",
      "remark": "",
      "cardType": 0,
      "cardName": "",
      "role": 0,
      "avatarPath": "http://example.com/avatar1.jpg",
      "shutUpTime": 1678886400, 
      "isDelete": false,
      "isSpecialConcerned": false,
      "isSpecialShield": false,
      "isRobot": false,
      "groupHonor": {},
      "memberRealLevel": 5,
      "memberLevel": 5,
      "globalGroupLevel": 10,
      "globalGroupPoint": 1000,
      "memberTitleId": 0,
      "memberSpecialTitle": "",
      "specialTitleExpireTime": "",
      "userShowFlag": 0,
      "userShowFlagNew": 0,
      "richFlag": 0,
      "mssVipType": 0,
      "bigClubLevel": 0,
      "bigClubFlag": 0,
      "autoRemark": "",
      "creditLevel": 0,
      "joinTime": 1609459200,
      "lastSpeakTime": 1678800000,
      "memberFlag": 0,
      "memberFlagExt": 0,
      "memberMobileFlag": 0,
      "memberFlagExt2": 0,
      "isSpecialShielded": false,
      "cardNameId": 0
    },
    {
      "uid": "some_uid_2",
      "qid": "some_qid_2",
      "uin": "987654321",
      "nick": "成员昵称2",
      "remark": "",
      "cardType": 0,
      "cardName": "",
      "role": 0,
      "avatarPath": "http://example.com/avatar2.jpg",
      "shutUpTime": 1678972800,
      "isDelete": false,
      "isSpecialConcerned": false,
      "isSpecialShield": false,
      "isRobot": false,
      "groupHonor": {},
      "memberRealLevel": 3,
      "memberLevel": 3,
      "globalGroupLevel": 8,
      "globalGroupPoint": 800,
      "memberTitleId": 0,
      "memberSpecialTitle": "",
      "specialTitleExpireTime": "",
      "userShowFlag": 0,
      "userShowFlagNew": 0,
      "richFlag": 0,
      "mssVipType": 0,
      "bigClubLevel": 0,
      "bigClubFlag": 0,
      "autoRemark": "",
      "creditLevel": 0,
      "joinTime": 1617228800,
      "lastSpeakTime": 1678805000,
      "memberFlag": 0,
      "memberFlagExt": 0,
      "memberMobileFlag": 0,
      "memberFlagExt2": 0,
      "isSpecialShielded": false,
      "cardNameId": 0
    }
  ],
  "message": "",
  "wording": "",
  "echo": null
}
```