# 发送群文本

**Endpoint:** `/send_group_msg`

**方法:** `POST`

**描述:** 发送群消息，目前仅支持发送纯文本消息。

**标签:** 消息相关 / 发送群聊消息

## 请求体 (Request Body)

发送消息时，需要提供群组ID和消息内容。

**Content-Type:** `application/json`

**参数:**

| 参数名    | 类型             | 是否必须 | 描述     |
| --------- | ---------------- | -------- | -------- |
| `group_id` | number 或 string | 是       | 目标群组ID |
| `message` | array            | 是       | 消息内容，目前仅支持文本消息数组 |

**`message` 数组元素结构:**

每个元素是一个对象，表示消息的一个组成部分。对于文本消息，结构如下：

| 参数名  | 类型   | 是否必须 | 描述     |
| ------- | ------ | -------- | -------- |
| `type`  | string | 是       | 消息类型，固定为 `"text"` |
| `data`  | object | 是       | 消息数据 |

**`data` 对象结构 (当 `type` 为 `"text"` 时):**

| 参数名 | 类型   | 是否必须 | 描述   |
| ------ | ------ | -------- | ------ |
| `text` | string | 是       | 文本内容 |

**请求示例:**

```json
{
  "group_id": "123456",
  "message": [
    {
      "type": "text",
      "data": {
        "text": "napcat"
      }
    }
  ]
}
```

## 响应 (Response)

**状态码:** `200 OK`

**描述:** 成功发送消息。

**Content-Type:** `application/json`

**响应体结构:**

| 参数名      | 类型   | 描述         |
| ----------- | ------ | ------------ |
| `status`    | string | 状态，成功为 `"ok"` |
| `retcode`   | number | 返回码       |
| `data`      | object | 响应数据     |
| `message`   | string | 错误信息（如果失败） |
| `wording`   | string | 详细错误描述（如果失败） |

**`data` 对象结构:**

| 参数名       | 类型   | 描述     |
| ------------ | ------ | -------- |
| `message_id` | number | 发送成功的消息ID |

**响应示例 (成功):**

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 696124706
  },
  "message": "",
  "wording": ""
}
```

**可能的返回码 (retcode):**

请参考Napcat的通用返回码说明文档，例如：
- `0`: 成功
- 非`0`: 表示失败，具体含义需查阅文档。