# API Endpoint: /send_group_msg

## 功能说明

向指定的群组发送消息。此接口主要用于发送包含艾特（`at`）消息段的群消息。虽然理论上 `message` 字段可以包含多种消息段（如文本、图片等），但提供的 Schema 示例和定义侧重于 `at` 消息段。请注意，实际支持的消息段类型可能依赖于你的具体 Napcat 配置和 OneBot 实现。

## Endpoint

`POST /send_group_msg`

## 请求参数

| 参数名    | 类型          | 必填 | 说明                                                                 |
| :-------- | :------------ | :--- | :------------------------------------------------------------------- |
| `group_id` | `number` 或 `string` | 是   | 群号                                                                 |
| `message` | `array`       | 是   | 消息段数组。数组中的每个元素代表消息的一部分（一个消息段）。每个元素应为一个对象。 |

### `message` 数组元素 (消息段) 说明

数组中的每个元素是一个消息段对象。根据提供的 Schema，此接口的定义示例主要围绕 `at` 消息段。一个消息段对象的结构如下：

| 参数名   | 类型     | 必填 | 说明                               |
| :------- | :------- | :--- | :--------------------------------- |
| `type`   | `string` | 是   | 消息段类型，例如 `"at"`             |
| `data`   | `object` | 是   | 消息段内容对象，具体内容取决于 `type` |

#### `data` 对象说明 (当 `type` 为 `"at"`)

| 参数名 | 类型                | 必填 | 说明                                   |
| :----- | :------------------ | :--- | :------------------------------------- |
| `qq`   | `number`, `string` 或 `"all"` | 是   | 艾特目标的QQ号，或者 `"all"` 表示艾特全体 |
| `name` | `string`            | 否   | 目标的群名片（在发送 `at` 消息时，此字段通常不填或被忽略） |

*注意：提供的 Schema 定义 `at` 消息段的内部属性为 `message`，但示例使用了 `data`。此处文档遵循示例中的 `data` 结构，这更符合 OneBot 标准。*

## 请求示例

发送一个包含艾特指定成员的消息（示例来源于Schema）：

```json
{
    "group_id": "123456",
    "message": [
        {
            "type": "at",
            "data": {
                "qq": "9866755482" // all为艾特全体
            }
        }
    ]
}
```

发送一个包含艾特全体的消息：

```json
{
    "group_id": "123456",
    "message": [
        {
            "type": "at",
            "data": {
                "qq": "all"
            }
        }
    ]
}
```

## 响应

### 状态码 `200`

表示请求成功，消息已发送（或进入发送队列）。

#### 响应体 Schema

| 参数名      | 类型      | 说明                                   |
| :---------- | :-------- | :------------------------------------- |
| `status`    | `string`  | 状态码，固定为 `"ok"`                   |
| `retcode`   | `number`  | 返回码                                 |
| `data`      | `object`  | 响应数据对象                           |
| `message`   | `string`  | 错误信息（如果 `status` 不是 `"ok"`）   |
| `wording`   | `string`  | 错误信息的友好提示（如果 `status` 不是 `"ok"`） |
| `echo`      | `string` 或 `null` | 请求时的 `echo` 字段，如果存在       |

#### `data` 对象说明 (当 `status` 为 `"ok"`)

| 参数名      | 类型      | 说明     |
| :---------- | :-------- | :------- |
| `message_id` | `number`  | 发送消息的消息ID |

#### 响应示例

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": "",
    "echo": null
}
```

## 错误处理

请参考响应体的 `status`, `retcode`, `message`, `wording` 字段来判断请求是否成功以及获取失败原因。当 `status` 为 `"ok"` 且 `retcode` 为 `0` 时，表示成功。其他情况通常表示失败，具体错误码和信息请参考返回内容。
