## API: /send_group_msg

### 接口说明

- **概述**: 发送群系统表情。这是一个用于向指定群聊发送消息的接口，特别说明了如何发送系统内置的表情。
- **URL**: `/send_group_msg`
- **方法**: `POST`
- **标签**: `消息相关/发送群聊消息`

### 请求参数

该接口通过请求体发送参数，请求体类型为 `application/json`。

| 参数名   | 类型          | 必填 | 描述                                                                 |
| :------- | :------------ | :--- | :------------------------------------------------------------------- |
| `group_id` | `number` 或 `string` | 是   | 群号。可以是数字或字符串类型。                                       |
| `message`| `array`       | 是   | 消息内容，由一个或多个消息段组成。在此接口中，主要用于发送表情消息段。 |

`message` 数组中的每个元素是一个消息段对象。对于发送系统表情，消息段对象结构如下：

| 字段名 | 类型   | 必填 | 描述                                                                                                    |
| :----- | :----- | :--- | :------------------------------------------------------------------------------------------------------ |
| `type` | `string` | 是   | 消息段类型。发送系统表情时，固定为 `"face"`。                                                           |
| `data` | `object` | 是   | 消息段数据。                                                                                              |

`data` 对象结构：

| 字段名 | 类型   | 必填 | 描述                                                                                                    |
| :----- | :----- | :--- | :------------------------------------------------------------------------------------------------------ |
| `id`   | `number` | 是   | 表情ID。请参考 [QQ机器人官方文档](https://bot.q.qq.com/wiki/develop/api-v2/openapi/emoji/model.html#EmojiType) 获取有效的表情ID列表。 |

### 请求示例

```json
{
    "group_id": "480972475",
    "message": [
        {
            "type": "face",
            "data": {
                "id": 37
            }
        }
    ]
}
```

### 响应说明

成功请求将返回 HTTP 状态码 `200`，响应体是 JSON 对象，包含请求处理结果。

#### 响应体结构

| 字段名    | 类型    | 必填 | 描述                                                                                                                                 |
| :-------- | :------ | :--- | :----------------------------------------------------------------------------------------------------------------------------------- |
| `status`  | `string`| 是   | 状态码，`"ok"` 表示成功，`"fail"` 或其他表示失败。                                                                                    |
| `retcode` | `number`| 是   | 返回码。`0` 通常表示成功。非 `0` 表示失败，具体含义参考 Napcat 的错误码文档。                                                              |
| `data`    | `object`| 是   | 响应数据体。请求成功时包含具体业务数据。                                                                                             |
| `message` | `string`| 是   | 错误信息。当 `status` 为 `"fail"` 时，此处通常包含简略的错误描述。                                                                       |
| `wording` | `string`| 是   | 详细的错误描述或提示信息。                                                                                                           |
| `echo`    | `string`| 否   | 回显字段，如果请求中包含 `echo` 字段，则响应会原样返回此字段。                                                                         |

`data` 对象结构：

| 字段名      | 类型    | 必填 | 描述     |
| :---------- | :------ | :--- | :------- |
| `message_id`| `number`| 是   | 发送成功的消息ID。 |

#### 响应示例 (成功)

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```