## API: /send_group_msg

*   **方法:** `POST`
*   **路径:** `/send_group_msg`
*   **分类:** 消息相关/发送群聊消息
*   **摘要:** 发送群消息 (发送群JSON)
*   **说明:** 该API用于向指定群聊发送消息，特别支持发送包含 `json` 消息段的消息。

### 请求体 (`application/json`)

发送消息需要提供群组ID和消息内容数组。

```json
{
  "group_id": "number or string",
  "message": [
    {
      "type": "json",
      "data": {
        "data": "string"
      }
    }
    // 可以包含其他消息段，但此接口侧重 json
  ]
}
```

*   **`group_id`** (必填): `number` 或 `string`. 要发送消息的群号。
*   **`message`** (必填): `array`. 消息段数组。对于此接口，通常至少包含一个 `json` 类型的消息段。
    *   **消息段对象**:
        *   **`type`** (必填): `string`. 消息段类型，此处必须为 `"json"`。
        *   **`data`** (必填): `object`. 消息段的具体数据。
            *   **`data`** (必填): `string`. 一个字符串，其内容是有效的 JSON 数据。此 JSON 数据的具体结构取决于你想要发送的特定类型的富媒体消息或卡片消息。

#### 请求体示例

```json
{
  "group_id": "123456",
  "message": [
    {
      "type": "json",
      "data": {
        "data": "{\"app\":\"com.tencent.miniapp\",\"config\":{\"forward":true,\"showSender":true},\"desc\":\"测试小程序\",\"meta\":{\"detail1\":{\"desc\":\"详情描述\",\"qqdocurl\":\"http://example.com\",\"title\":\"标题\"}},\"prompt\":\"这是条小程序消息\",\"title\":\"小程序标题\",\"ver\":\"1.0\"}"
      }
    }
  ]
}
```

### 响应

#### 状态码 `200` (成功)

发送成功时返回的消息信息。

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 696124706
  },
  "message": "",
  "wording": "",
  "echo": null
}
```

*   **`status`**: `string`. 调用状态，成功时为 `"ok"`。
*   **`retcode`**: `number`. 返回码。
*   **`data`**: `object`. 包含具体的响应数据。
    *   **`message_id`**: `number`. 成功发送消息后生成的消息ID。
*   **`message`**: `string`. 错误信息（成功时通常为空）。
*   **`wording`**: `string`. 错误信息的友好提示（成功时通常为空）。
*   **`echo`**: `string` or `null`. 用户提供的 echo 字段，如果请求中提供了。

### 注意事项

*   `message` 字段是一个数组，理论上可以包含多种消息段，但 `/send_group_msg` 这个 endpoint 主要针对发送 `json` 类型的消息。
*   `data.data` 字段中的 JSON 字符串内容需要符合腾讯相关的协议规范，用于渲染特定的富媒体消息类型（如小程序卡片、群公告卡片等）。不正确的 JSON 格式或内容可能导致消息发送失败或无法正确显示。
*   `group_id` 可以是数字或字符串，具体取决于实际使用的适配器和配置。