# API文档: 发送群语音

**Endpoint:** `POST /send_group_msg`

**分类:** 消息相关/发送群聊消息

**描述:** 发送群消息，此接口特指发送语音消息。

## 请求体 (Request Body)

发送语音消息需要在请求体中包含 `group_id` 和 `message` 字段。

| 参数名   | 类型              | 必填 | 描述             |
| :------- | :---------------- | :--- | :--------------- |
| `group_id` | number 或 string | 是   | 目标群号         |
| `message`  | array             | 是   | 消息内容数组     |

### `message` 字段说明

`message` 字段是一个数组，对于发送语音消息，数组中应包含一个类型为 `record` 的消息段。

```json
[
  {
    "type": "record",
    "data": {
      "file": "string" // 语音文件路径或URL
    }
  }
]
```

**`record` 消息段参数:**

| 参数名 | 类型   | 必填 | 描述                                                                 |
| :----- | :----- | :--- | :------------------------------------------------------------------- |
| `type` | string | 是   | 消息段类型，固定为 `"record"`                                      |
| `data` | object | 是   | 消息段数据                                                           |
| `file` | string | 是   | 语音文件的路径或 URL。<br/>支持本地路径 (`file://...`) 或网络 URL (`http://...`, `https://...`). |

## 响应 (Response)

成功发送消息后，将返回包含发送消息结果的 JSON 对象。

### 状态码 200

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 696124706
  },
  "message": "",
  "wording": "",
  "echo": null
}
```

**响应字段说明:**

| 参数名       | 类型    | 描述         |
| :----------- | :------ | :----------- |
| `status`     | string  | 状态码，`ok` 表示成功。 |
| `retcode`    | number  | 返回码。     |
| `data`       | object  | 结果数据。   |
| `data.message_id` | number | 发送成功的消息 ID。 |
| `message`    | string  | 错误消息。   |
| `wording`    | string  | 错误提示。   |
| `echo`       | string? | Echo 字段。  |

## 请求示例 (Example Request)

```json
{
    "group_id": "123456",
    "message": [
        {
            "type": "record",
            "data": {
                // 本地路径
                "file": "file://D:/a.mp3"
                
                // 网络路径
                // "file": "http://xxx.mp3"
            }
        }
    ]
}
```

## 成功响应示例 (Example Response)

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```
