# POST /send_group_msg

## 接口名称

发送群消息

## 接口说明

向指定的群聊发送一条或多条消息段。

虽然接口摘要是“发送群视频”，但实际功能是发送群消息，支持发送多种类型的消息段，其中示例展示了如何发送视频消息。

## Endpoint

`POST /send_group_msg`

## 请求参数

| 字段名   | 类型                                | 是否必须 | 说明                                                                                                                                                              | 示例                                                                                                                               |
| :------- | :---------------------------------- | :------- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------- | :--------------------------------------------------------------------------------------------------------------------------------- |
| `group_id` | `number` 或 `string`              | 是       | 目标群号。                                                                                                                                                        | `123456`                                                                                                                           |
| `message`  | `array` of [消息段](#消息段结构) | 是       | 要发送的消息内容，可以是一个消息段数组。**注意：** 虽然示例仅展示了视频消息，但实际支持发送多种消息类型，如文本、图片、表情等。                                             | `[ { "type": "text", "data": { "text": "你好" } }, { "type": "image", "data": { "file": "base64://..." } } ]` |

### 消息段结构

`message` 字段是一个数组，数组的每个元素代表一个消息段。每个消息段必须包含 `type` 和 `data` 字段。

例如，发送视频消息的结构如下：

```json
{
  "type": "video",
  "data": {
    "file": "string" // 视频文件路径或URL (file://..., http://..., base64://...)
  }
}
```

> **提示:** 关于支持的消息段类型和每种类型的 `data` 结构，请参考 Napcat 的[消息类型文档](链接待补充)。

## 请求示例

发送一个视频消息到群组 `123456`。

```json
{
    "group_id": "123456",
    "message": [
        {
            "type": "video",
            "data": {
                // 本地路径
                "file": "file://D:/a.mp4"
                
                // 网络路径
                // "file": "http://xxx.mp4"
                
                // base64编码
                // "file": "base64://..."
            }
        }
    ]
}
```

## 响应结构

接口返回一个JSON对象，表示操作结果。

```json
{
  "status": "string",
  "retcode": "number",
  "data": {
    "message_id": "number"
  },
  "message": "string",
  "wording": "string",
  "echo": "string" // 可能为 null
}
```

| 字段名       | 类型     | 说明                                  |
| :----------- | :------- | :------------------------------------ |
| `status`     | `string` | 请求状态，通常为 `ok` 或 `failed`。     |
| `retcode`    | `number` | 返回码，`0` 表示成功，非 `0` 表示失败。 |
| `data`       | `object` | 响应数据体。                          |
| `data.message_id` | `number` | 发送成功的消息ID。                    |
| `message`    | `string` | 错误信息（仅在失败时出现）。          |
| `wording`    | `string` | 供用户观看的提示信息。                |
| `echo`       | `string` | 发送请求时携带的 echo 字段。          |

## 响应示例

发送成功时的响应示例：

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": "",
    "echo": null
}
```

## 错误处理

如果 `status` 为 `failed` 且 `retcode` 非 `0`，请根据 `retcode`、`message` 和 `wording` 字段判断错误原因。
