## API: /send_private_msg

### 接口描述

此接口用于向指定用户发送包含图片的私聊消息。请求体中需要提供目标用户的 `user_id` 和一个消息数组 `message`，其中每个消息对象必须是类型为 `image` 的图片消息。

**Method:** `POST`

**Tag:** 消息相关/发送私聊消息

### 请求参数

请求体是一个 JSON 对象，包含以下字段：

| 字段名   | 类型         | 必填 | 描述                                                                | 示例                                                              |
| :------- | :----------- | :--- | :------------------------------------------------------------------ | :---------------------------------------------------------------- |
| `user_id` | `number` 或 `string` | 是   | 接收消息的用户 QQ 号。                                                | `123456`                                                          |
| `message` | `array`      | 是   | 消息内容数组，数组中的每个元素代表一个消息段。此处仅支持类型为 `image` 的消息段。 | `[ { "type": "image", "data": { "file": "file://D:/a.jpg" } } ]` |

#### `message` 数组元素 (图片消息段)

数组中的每个对象是一个消息段，对于发送图片，对象结构如下：

| 字段名    | 类型     | 必填 | 描述                                                                                                                                                              | 示例             |
| :-------- | :------- | :--- | :-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | :--------------- |
| `type`    | `string` | 是   | 消息段类型，发送图片时固定为 `image`。                                                                                                                              | `"image"`      |
| `data`    | `object` | 是   | 图片消息段的数据。                                                                                                                                                | `{ "file": "..." }` |

##### `data` 对象字段

| 字段名    | 类型     | 必填 | 描述                                                                                                                                                              | 示例                                                                 |
| :-------- | :------- | :--- | :-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------------- |
| `file`    | `string` | 是   | 图片文件的来源，支持以下格式：<br>- `file://...`: 本地文件路径<br>- `http://...` 或 `https://...`: 网络图片 URL<br>- `base64://...`: Base64 编码的图片数据                   | `"file://D:/a.jpg"`<br>`"http://example.com/img.png"`<br>`"base64://..."` |
| `summary` | `string` | 否   | 图片的外显文本，当图片无法显示时会显示此文本，默认为 `[图片]`。                                                                                                            | `"这是一张可爱的图片"`  |

### 响应格式

成功发送消息后，接口将返回一个 JSON 对象。

| 字段名    | 类型     | 描述                                   | 示例        |
| :-------- | :------- | :------------------------------------- | :---------- |
| `status`  | `string` | 请求处理状态，`ok` 表示成功。            | `"ok"`    |
| `retcode` | `number` | 返回码，`0` 通常表示成功。               | `0`         |
| `data`    | `object` | 响应数据，包含消息发送后的信息。         | `{ "message_id": 12345 }` |
| `message` | `string` | 详细信息，通常在错误时包含错误描述。       | `""`        |
| `wording` | `string` | 更友好的提示信息。                       | `""`        |
| `echo`    | `string` | 回显信息，如果请求时提供了 `echo` 字段。 | `null`      |

#### `data` 对象字段

| 字段名       | 类型     | 描述       |
| :----------- | :------- | :--------- |
| `message_id` | `number` | 发送成功的消息的唯一 ID。 |

### 示例

#### 请求示例

```json
{
    "user_id": "123456",
    "message": [
        {
            "type": "image",
            "data": {
                "file": "file://D:/a.jpg"
            }
        }
    ]
}
```

```json
{
    "user_id": 654321,
    "message": [
        {
            "type": "image",
            "data": {
                "file": "http://i0.hdslb.com/bfs/archive/c8fd97a40bf79f03e7b76cbc87236f612caef7b2.png",
                "summary": "网络图片示例"
            }
        }
    ]
}
```

```json
{
    "user_id": "987654",
    "message": [
        {
            "type": "image",
            "data": {
                "file": "base64://xxxxxxxx"
            }
        }
    ]
}
```

#### 响应示例 (成功)

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```