# 发送私聊消息

向指定用户发送私聊消息。

**Endpoint:** `POST /send_private_msg`

**描述:** 发送私聊消息。

## 请求体 (Request Body)

请求体是一个 JSON 对象，包含以下字段：

| 参数名   | 类型   | 是否必须 | 说明                     | 示例        |
| :------- | :----- | :------- | :----------------------- | :---------- |
| `user_id` | `number` 或 `string` | 是       | 接收消息的用户 QQ 号码。 | `123456`    |
| `message` | `array` | 是       | 消息内容，消息段数组。   | `[{...}, {...}]` |

### `message` 字段说明

`message` 字段是一个数组，包含一个或多个消息段 (Message Segment)。每个消息段是一个对象，必须包含 `type` 和 `data` 字段。

常见的消息段类型包括：

-   **`text` (文本消息)**
    -   `type`: `"text"`
    -   `data`: 一个对象，包含 `text` 字段 (string, 文本内容)。
    -   示例: `{"type": "text", "data": {"text": "你好"}}`

-   **`reply` (回复消息)**
    -   `type`: `"reply"`
    -   `data`: 一个对象，包含 `id` 字段 (number 或 string, 要回复的消息 ID)。
    -   示例: `{"type": "reply", "data": {"id": 123456789}}`

**注意:** 如果要回复某条消息，通常需要将 `reply` 消息段放在数组的第一个位置。

### 请求示例

```json
{
    "user_id": 123456,
    "message": [
        {
            "type": "reply",
            "data": {
                "id": 1263753202
            }
        },
        {
            "type": "text",
            "data": {
                "text": "回复你了"
            }
        }
    ]
}
```

## 响应体 (Response Body)

响应体是一个 JSON 对象，表示操作结果，遵循 OneBot 标准响应格式。

| 参数名    | 类型     | 说明                                    |
| :-------- | :------- | :-------------------------------------- |
| `status`  | `string` | 执行状态，`ok` 表示成功，`async` 表示异步。 |
| `retcode` | `number` | 返回码，`0` 通常表示成功。                |
| `data`    | `object` | 响应数据，具体内容取决于接口。          |
| `message` | `string` | 错误信息，当 `status` 不为 `ok` 时有效。  |
| `wording` | `string` | 详细的错误描述。                        |
| `echo`    | `string` | 请求的 `echo` 字段，如果请求中携带。      |

### `data` 字段说明

当 `status` 为 `ok` 时，`data` 字段包含以下内容：

| 参数名       | 类型     | 说明     |
| :----------- | :------- | :------- |
| `message_id` | `number` | 发送消息的消息 ID。 |

### 响应示例

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```
