# 发送私聊系统表情

## 简介

此 API 用于向指定用户发送包含一个或多个系统表情的私聊消息。尽管描述中提到了"发送群消息"，但根据接口名称 `/send_private_msg` 和请求参数 `user_id`，此接口实际功能是发送私聊消息，且消息内容仅支持系统表情 (`face` 类型的消息段)。

请注意：该接口定义特化为仅支持发送系统表情，若需发送其他类型的消息（文本、图片等）或组合消息，请参考更通用的私聊消息发送接口。

## Endpoint

`POST /send_private_msg`

## 请求参数

请求体为一个 JSON 对象，包含以下字段：

| 字段名   | 类型      | 描述                                                                 | 是否必须 | 示例     |
| :------- | :-------- | :------------------------------------------------------------------- | :------- | :------- |
| `user_id` | `number` 或 `string` | 接收消息的用户 QQ 号。                                               | 是       | `123456` |
| `message` | `array`   | 消息内容，包含一个或多个消息段。对于此特定接口，数组元素必须是 `face` 类型的消息段。 | 是       | `[{"type": "face", "data": {"id": 37}}]` |

**`message` 数组中的 `face` 消息段结构:**

| 字段名 | 类型   | 描述                                     | 是否必须 | 示例   |
| :----- | :----- | :--------------------------------------- | :------- | :----- |
| `type` | `string` | 消息段类型，固定为 `"face"`。              | 是       | `"face"` |
| `data` | `object` | 消息段数据，一个包含表情 ID 的对象。     | 是       | `{"id": 37}` |

**`data` 对象中的字段:**

| 字段名 | 类型   | 描述             | 是否必须 | 示例 |
| :----- | :----- | :--------------- | :------- | :--- |
| `id`   | `number` | 系统表情的 ID。 | 是       | `37` |

关于系统表情 ID 的参考，可以查阅 [https://bot.q.qq.com/wiki/develop/api-v2/openapi/emoji/model.html#EmojiType](https://bot.q.qq.com/wiki/develop/api-v2/openapi/emoji/model.html#EmojiType)（注意：此链接指向的是 QQ 官方机器人文档，Napcat 可能支持更多或不同的表情，具体请以实际测试为准）。

## 请求示例

```json
{
    "user_id": "123456",
    "message": [
        {
            "type": "face",
            "data": {
                "id": 37
            }
        },
        {
            "type": "face",
            "data": {
                "id": 54
            }
        }
    ]
}
```

## 响应说明

成功请求将返回一个 JSON 对象，包含以下标准字段：

| 字段名    | 类型     | 描述                               | 示例     |
| :-------- | :------- | :--------------------------------- | :------- |
| `status`  | `string` | 响应状态，`"ok"` 表示成功。        | `"ok"` |
| `retcode` | `number` | 响应码，`0` 通常表示成功。          | `0`      |
| `data`    | `object` | 响应数据体，包含消息发送成功的详情。 | `{"message_id": 696124706}` |
| `message` | `string` | 错误消息（如果 `status` 不是 `"ok"`）。 | `""`     |
| `wording` | `string` | 错误提示的可读文本。             | `""`     |
| `echo`    | `string` | 请求的 echo 字段（如果提供了）。   | `"some_echo"` |

`data` 对象包含以下字段：

| 字段名     | 类型     | 描述       | 示例        |
| :--------- | :------- | :--------- | :---------- |
| `message_id` | `number` | 发送消息的消息 ID。 | `696124706` |

## 响应示例

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": "",
    "echo": null
}
```

## 备注

*   此接口严格按照其定义，只接受包含 `face` 类型消息段的 `message` 数组。发送其他类型的消息段会导致失败或未定义行为。
*   系统表情 ID 的有效性取决于 QQ 协议版本和客户端支持。
