# 发送私聊语音

## Endpoint

`POST /send_private_msg`

## 说明

此接口用于向指定用户发送私聊语音消息。

## 参数

请求体 (Request Body) 为 `application/json` 格式：

| 参数名    | 类型                                   | 必填 | 说明                                      |
| --------- | -------------------------------------- | ---- | ----------------------------------------- |
| `user_id` | `number` 或 `string`                   | 是   | 接收私聊语音消息的用户 QQ 号                  |
| `message` | `array` of [消息段](#消息段)             | 是   | 语音消息内容，必须是 **仅包含一个语音消息段** 的数组 |

### 消息段 (Message Segment)

此接口的 `message` 数组根据当前 OpenAPI 定义，**仅支持一个语音消息段**。

**语音消息段 (`type: "record"`)**

| 参数名      | 类型     | 必填 | 说明                                                                                                    |
| --------- | -------- | ---- | ------------------------------------------------------------------------------------------------------- |
| `type`    | `string` | 是   | 消息段类型，固定为 `"record"`                                                                            |
| `data`    | `object` | 是   | 消息段数据                                                                                               |
| `data.file` | `string` | 是   | 语音文件，支持 `file://` (本地文件路径) 或 `http://`, `https://` (网络 URL) 等格式。具体支持格式取决于 OneBot 实现。 |

## 请求示例

```json
{
    "user_id": "123456",
    "message": [
        {
            "type": "record",
            "data": {
                // 本地路径
                "file": "file://D:/a.mp3"

                // 网络路径
                // "file": "http://xxx.mp3"
            }
        }
    ]
}
```

## 响应

响应体 (Response Body) 为 `application/json` 格式，标准响应结构：

| 参数名    | 类型     | 说明                                           |
| --------- | -------- | ---------------------------------------------- |
| `status`  | `string` | 状态，`ok` 表示成功，`failed` 表示失败          |
| `retcode` | `number` | 返回码，参考 OneBot 规范                        |
| `data`    | `object` | 响应数据，成功时包含 `message_id`               |
| `message` | `string` | 错误信息                                       |
| `wording` | `string` | 错误信息的友好提示                              |
| `echo`    | `string` | 请求时携带的 echo 字段，如果携带了的话           |

### 响应数据 (`data`)

| 参数名      | 类型   | 说明       |
| ----------- | ------ | ---------- |
| `message_id` | `number` | 发送成功的消息 ID |

## 响应示例

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```

## 错误码

参考 OneBot 规范及 OneBot 实现（如 Napcat）的错误码定义。

