# 发送私聊消息 - 视频

**Endpoint:** `/send_private_msg`

**方法:** `POST`

**简介:** 向指定用户发送包含视频的私聊消息。

**描述:** 此API用于向指定用户发送一个或多个消息段组成的私聊消息，特别支持发送视频。

## 请求体 (`application/json`)

| 参数名    | 类型           | 必填 | 描述                               |
| :-------- | :------------- | :--- | :--------------------------------- |
| `user_id` | `number` 或 `string` | 是   | 接收消息的用户QQ号。                |
| `message` | `array<object>` | 是   | 消息内容，由消息段组成的数组。**目前此API只支持视频消息段。** |

### `message` 数组元素结构 (视频消息段)

消息段为对象，当发送视频时，其结构如下：

| 参数名 | 类型   | 必填 | 描述                                  |
| :----- | :----- | :--- | :------------------------------------ |
| `type` | `string` | 是   | 消息段类型，固定为 `"video"`。        |
| `data` | `object` | 是   | 视频消息段数据。                      |

#### `data` 对象结构 (视频消息段)

| 参数名 | 类型   | 必填 | 描述                                                                                             |
| :----- | :----- | :--- | :----------------------------------------------------------------------------------------------- |
| `file` | `string` | 是   | 视频文件路径。支持 `file://` 开头的本地文件路径或 `http://`, `https://` 开头的网络URL。**不支持base64。** |

### 请求示例

```json
{
    "user_id": 123456,
    "message": [
        {
            "type": "video",
            "data": {
                "file": "file:///path/to/your/video.mp4"
            }
        }
    ]
}
```

或者使用网络URL：

```json
{
    "user_id": "123456",
    "message": [
        {
            "type": "video",
            "data": {
                "file": "http://example.com/videos/amazing.mp4"
            }
        }
    ]
}
```

## 响应体 (`application/json`)

| 参数名    | 类型    | 必填 | 描述                     |
| :-------- | :------ | :--- | :----------------------- |
| `status`  | `string` | 是   | 状态，`"ok"` 表示成功。 |
| `retcode` | `number` | 是   | 返回码。                   |
| `data`    | `object` | 是   | 响应数据对象。             |
| `message` | `string` | 是   | 错误信息。                 |
| `wording` | `string` | 是   | 提示信息。                 |
| `echo`    | `string` 或 `null` | 是   | echo回显字段。            |

### `data` 对象结构

| 参数名     | 类型    | 必填 | 描述   |
| :--------- | :------ | :--- | :----- |
| `message_id` | `number` | 是   | 发送消息的消息ID。 |

### 响应示例 (成功)

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```

## 错误处理

请参考响应体中的 `status`, `retcode`, `message`, `wording` 字段来判断请求是否成功以及获取错误信息。
