# API 文档: 撤回消息

## Endpoint

`POST /delete_msg`

## 描述

该API用于撤回指定的消息。根据 OneBot 规范，只有在消息发送后的一小段时间内可以撤回，且部分类型的消息（如接收到的群聊消息）无法撤回。

## 请求参数

请求体使用 `application/json` 格式。

| 参数名      | 类型         | 是否必需 | 描述     | 示例       |
| ----------- | ------------ | -------- | -------- | ---------- |
| `message_id` | number 或 string | 是       | 要撤回的消息ID | `1768656698` |

## 响应

成功时返回JSON对象。

| 参数名   | 类型    | 描述       | 示例值        |
| -------- | ------- | ---------- | ------------- |
| `status` | string  | 状态码，通常为 "ok" | `"ok"`        |
| `retcode`| number  | 返回码     | `0` 或其他    |
| `data`   | null    | 接口返回数据，对于此接口通常为空   | `null`        |
| `message`| string  | 错误信息（成功时通常为空）   | `""` 或错误信息 |
| `wording`| string  | 错误信息的友好表达（成功时通常为空） | `""` 或错误信息 |
| `echo`   | string? | 原样返回请求中的 echo 字段（如果存在），可用于标识请求 | `"your_echo_data"` |

## 响应示例

```json
{
  "status": "ok",
  "retcode": 0,
  "data": null,
  "message": "",
  "wording": "",
  "echo": "your_echo_data"
}
```

## 错误处理

如果撤回失败，`retcode` 将为非零值，并且 `message` 和 `wording` 字段将包含详细的错误信息。

## 使用示例

### cURL

```bash
curl -X POST \
  -H "Content-Type: application/json" \
  -d '{"message_id": 1768665432, "echo": "my_request_id_123"}' \
  http://your-napcat-api-address/delete_msg
```

### Python

```python
import requests

url = "http://your-napcat-api-address/delete_msg"
payload = {"message_id": 1768665432, "echo": "my_request_id_123"}
headers = {"Content-Type": "application/json"}

response = requests.post(url, json=payload, headers=headers)

print(response.json())
```

### JavaScript (Fetch API)

```javascript
fetch("http://your-napcat-api-address/delete_msg", {
  method: "POST",
  headers: {
    "Content-Type": "application/json"
  },
  body: JSON.stringify({ message_id: 1768665432, echo: "my_request_id_123" })
})
.then(response => response.json())
.then(data => console.log(data))
.catch(error => console.error("Error:", error));
```

### Java (OkHttp)

```java
import okhttp3.*;
import java.io.IOException;

public class DeleteMessage {
    public static void main(String[] args) throws IOException {
        OkHttpClient client = new OkHttpClient();

        MediaType JSON = MediaType.get("application/json; charset=utf-8");
        String json = "{\"message_id\": 1768665432, \"echo\": \"my_request_id_123\"}";
        RequestBody body = RequestBody.create(json, JSON);

        Request request = new Request.Builder()
                .url("http://your-napcat-api-address/delete_msg")
                .post(body)
                .build();

        try (Response response = client.newCall(request).execute()) {
            if (!response.isSuccessful()) throw new IOException("Unexpected code " + response);
            System.out.println(response.body().string());
        }
    }
}
```

### C# (HttpClient)

```csharp
using System;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;

public class DeleteMessage
{
    public static async Task Main(string[] args)
    {
        using var httpClient = new HttpClient();
        var messageId = 1768665432;
        var echo = "my_request_id_123";
        var jsonContent = $ accommodations{{\"message_id\": {messageId}, \"echo\": \"{echo}\"}};
        var content = new StringContent(jsonContent, Encoding.UTF8, "application/json");

        var response = await httpClient.PostAsync("http://your-napcat-api-address/delete_msg", content);

        if (response.IsSuccessStatusCode)
        {
            var result = await response.Content.ReadAsStringAsync();
            Console.WriteLine(result);
        }
        else
        {n            Console.WriteLine($"Error: {response.StatusCode}");
        }
    }
}
```