# 获取小程序卡片 (ARK消息)

`POST /get_mini_app_ark`

**Summary:** 获取小程序卡片所需的ARK数据结构。

**Description:** 此API用于根据提供的参数生成QQ或TIM聊天中可用的“小程序卡片”（本质上是一种ARK消息）。这些ARK数据可以直接用于发送消息API（如 `send_msg`）中。

**Tags:** 账号相关

## Request Body

请求体为一个JSON对象，包含生成小程序卡片的各项参数。

| 字段名称        | 类型     | 是否必需 | 描述                                                                                                |
| :-------------- | :------- | :------- | :-------------------------------------------------------------------------------------------------- |
| `type`          | `string` | 否       | 卡片类型，目前支持 `bili` (B站) 和 `weibo` (微博)。**如果仅填写必需参数，此字段为必需。**                       |
| `title`         | `string` | 是       | 卡片标题。                                                                                          |
| `desc`          | `string` | 是       | 卡片内容描述。                                                                                      |
| `picUrl`        | `string` | 是       | 卡片缩略图的图片URL。                                                                               |
| `jumpUrl`       | `string` | 是       | 点击卡片跳转的链接。对于小程序类型，这通常是小程序的页面路径。                                        |
| `iconUrl`       | `string` | 否       | 应用图标URL。                                                                                       |
| `sdkId`         | `string` | 否       | SDK ID。                                                                                            |
| `appId`         | `string` | 否       | App ID。                                                                                            |
| `scene`         | `number`\`string` | 否       | 场景值。                                                                                            |
| `templateType`  | `number`\`string` | 否       | 模板类型。                                                                                          |
| `businessType`  | `number`\`string` | 否       | 业务类型。                                                                                          |
| `verType`       | `number`\`string` | 否       | 版本类型。                                                                                          |
| `shareType`     | `number`\`string` | 否       | 分享类型。                                                                                          |
| `versionId`     | `string` | 否       | 版本 ID。                                                                                           |
| `withShareTicket` | `number`\`string` | 否       | 是否带 Share Ticket。                                                                               |
| `rawArkData`    | `boolean`\`string` | 否       | 返回原始的ARK数据字符串而不是结构体。默认返回结构体。                                               |

**注意:** `title`, `desc`, `picUrl`, `jumpUrl` 是生成卡片时最基本的必需参数。

### Request Example

```json
{
  "type": "bili",
  "title": "拾雪的一天",
  "desc": "vlog记录一天的生活",
  "picUrl": "https://thirdqq.qlogo.cn/g?b=oidb&k=09ElpZZZUTHFhoIlvs0lFg&kti=ZyBvjxHhVOI&s=640",
  "jumpUrl": "pages/video/video?bvid=BV1GJ411x7h7/"
}
```

## Response

### 状态码: 200 成功

**Description:** 成功获取小程序卡片对应的ARK数据。返回的数据可以直接用于构建消息并发送。

**Response Body:** 返回一个JSON对象，其结构即为可以直接用于消息发送的ARK数据。具体的字段结构取决于Go-CQHTTP或OICQ等底层实现对ARK消息的定义，通常包含`type`和`data`等字段。

**Example Response:**

```json
{
  "type": "app",
  "data": "<?xml version='1.0' encoding='UTF-8' standalone='yes' ?>\n<msg serviceID=\"10048\" templateID=\"10048\" action=\"plugin\" a_action=\"plugin\" i_action=\"plugin\" brief=\"拾雪的一天\" sourceStr=\"\" flag=\"3\" toparentchat=\"0\" style=\"0\" ctime=\"1678819200\">\n    <item layout=\"2\">\n        <image src=\"https://thirdqq.qlogo.cn/g?b=oidb&amp;k=09ElpZZZUTHFhoIlvs0lFg&amp;kti=ZyBvjxHhVOI&amp;s=640\" minWidth=\"100\" minHeight=\"100\" maxWidth=\"100\" maxHeight=\"100\"/>\n        <item layout=\"5\">\n            <title>拾雪的一天</title>\n            <summary>vlog记录一天的生活</summary>\n        </item>\n    </item>\n    <source name=\"B站\" icon=\"https://qzonestyle.gtimg.cn/qzone/app/app_store/mall/icon/10048/10048_icon.png\" url=\"http://baidu.com\" a_action=\"\" i_action=\"\" action=\"\"/>\n</msg>"
}
```
(注意：实际的`data`字段内容是XML字符串，会根据你提供的参数生成)
