## API: 发送私聊骰子消息

### Endpoint
`/send_private_msg`

### 功能说明

向指定的私聊会话发送一个“骰子”类型的消息元素。

### 请求地址

`/send_private_msg`

### 请求方法

`POST`

### 请求参数

请求体为 JSON 对象，包含以下参数：

| 参数名    | 类型            | 必需 | 说明                                                                                                | 示例       |
| :-------- | :-------------- | :--- | :-------------------------------------------------------------------------------------------------- | :--------- |
| `user_id` | `number` / `string` | 是   | 接收消息的用户QQ号。                                                                                | `123456`   |
| `message` | `array`         | 是   | 消息内容，固定为包含一个 `type: 'dice'` 元素对象的数组。

数组中对象的结构如下：
- `type`: 消息元素类型，固定为 `"dice"`。
- `data`: 元素数据，一个空对象即可。**注意：`result` 字段目前暂不可用，发送时请不要包含此字段。** | `[ { "type": "dice" } ]` |

### 响应数据

成功时返回 JSON 对象，包含以下字段：

| 字段名    | 类型     | 说明             |
| :-------- | :------- | :--------------- |
| `status`  | `string` | 状态，`"ok"`     |
| `retcode` | `number` | 返回码           |
| `data`    | `object` | 响应数据           |
| `message` | `string` | 错误信息（成功时为空） |
| `wording` | `string` | 友好提示（成功时为空） |

`data` 对象包含以下字段：

| 字段名      | 类型   | 说明         |
| :---------- | :----- | :----------- |
| `message_id`| `number` | 发送消息的消息ID |

### 响应示例

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 696124706
  },
  "message": "",
  "wording": ""
}
```

### 注意事项

*   根据提供的OpenAPI规范，`message` 元素中的 `data.result` 字段（用于指定骰子结果）目前暂不可用。发送骰子消息时，`data` 字段应为空对象 `{}` 或直接忽略 `data` 字段（如果SDK支持）。通常，只需要发送 `[ { "type": "dice" } ]` 即可发送一个随机结果的骰子。
*   虽然OpenAPI规范的schema中错误地出现了 `group_id`，但根据Endpoint `/send_private_msg` 和示例，此API应是用于发送私聊消息，接收者通过 `user_id` 指定。