# POST /send_private_msg

**发送私聊自定义音乐卡片**

向指定用户发送一条自定义音乐卡片消息。

## 请求

- **方法:** `POST`
- **URL:** `/send_private_msg`
- **Content-Type:** `application/json`

### 请求体 (`application/json`)

| 参数名  | 类型             | 必填 | 描述                                                                 |
| :------ | :--------------- | :--- | :------------------------------------------------------------------- |
| user_id | `number` 或 `string` | 是   | 接收私聊消息的用户 ID。                                              |
| message | `array`          | 是   | 消息内容，此处应为一个包含自定义音乐卡片消息对象的数组。详情见下方。 |

**自定义音乐卡片消息对象 (`message` 数组项)**

一个包含音乐卡片信息的 JSON 对象。

| 参数名 | 类型   | 必填 | 说明                                     |
| :----- | :----- | :--- | :--------------------------------------- |
| type   | `string` | 是   | 消息段类型，固定为 `"music"`。             |
| data   | `object` | 是   | 音乐卡片的详细数据。详情见下方。         |

**音乐卡片详细数据对象 (`data`)**

包含音乐卡片具体内容的 JSON 对象。

| 参数名 | 类型     | 必填 | 说明           |
| :----- | :------- | :--- | :------------- |
| type   | `string` | 是   | 卡片类型，固定为 `"custom"`。 |
| url    | `string` | 是   | 点击卡片跳转的链接。 |
| audio  | `string` | 是   | 音乐音频文件的链接。 |
| title  | `string` | 是   | 音乐卡片的标题。 |
| image  | `string` | 是   | 音乐卡片的封面图片链接。 |

### 请求体示例

```json
{
  "user_id": 123456789,
  "message": [
    {
      "type": "music",
      "data": {
        "type": "custom",
        "url": "https://example.com/music-link",
        "audio": "https://example.com/music.mp3",
        "title": "这是一首很棒的音乐",
        "image": "https://example.com/cover.jpg"
      }
    }
  ]
}
```

## 响应

- **状态码:** `200 OK`
- **Content-Type:** `application/json`

### 响应体 (`application/json`)

| 参数名    | 类型      | 必填 | 说明             |
| :-------- | :-------- | :--- | :--------------- |
| status    | `string`  | 是   | 响应状态，`"ok"` 表示成功。 |
| retcode   | `number`  | 是   | 返回码。         |
| data      | `object`  | 是   | 响应数据。       |
| message   | `string`  | 是   | 错误信息（成功时通常为空）。 |
| wording   | `string`  | 是   | 错误描述（成功时通常为空）。 |
| echo      | `string?` | 是   | 请求时携带的 echo 字段（如果存在）。 |

**响应数据对象 (`data`)**

| 参数名      | 类型     | 必填 | 说明     |
| :---------- | :------- | :--- | :------- |
| message_id  | `number` | 是   | 发送成功后的消息 ID。 |

### 响应示例 (成功)

```json
{
  "status": "ok",
  "retcode": 0,
  "data": {
    "message_id": 696124706
  },
  "message": "",
  "wording": "",
  "echo": null
}
```
