# `POST /send_group_msg` 发送群文件

**标签:** 消息相关/发送群聊消息

向指定群聊发送文件消息。

## 请求体 (Request Body)

使用 `application/json` 格式。

| 参数      | 类型                                  | 必须 | 描述                                                                                                |
| --------- | ------------------------------------- | ---- | --------------------------------------------------------------------------------------------------- |
| `group_id` | `number` 或 `string`                  | 是   | 群号                                                                                                |
| `message` | `array` of [文件消息](#文件消息)      | 是   | 消息内容，必须是文件消息类型的数组。注意：此API仅支持发送文件消息，数组中应只包含类型为 `file` 的消息段。 |

### 文件消息 (Message Segment Type: `file`)

当 `message` 数组中的项类型为 `file` 时，其 `data` 字段结构如下：

| 参数   | 类型     | 必须 | 描述                                                                                                                                |
| ------ | -------- | ---- | ----------------------------------------------------------------------------------------------------------------------------------- |
| `type` | `string` | 是   | 消息段类型，固定为 `file`                                                                                                           |
| `data` | `object` | 是   | 文件数据                                                                                                                            |
| `data.file` | `string` | 是   | 文件路径、URL 或 Base64 数据。支持格式：<br/>- 本地路径: `file:///path/to/your/file` (或 `file://D:/path/to/your/file`)<br/>- 网络URL: `http://...` 或 `https://...`<br/>- Base64 或 DataUrl 编码数据 |
| `data.name` | `string` | 否   | 文件名 (可选，某些情况下可能需要指定)                                                                                                 |

#### Request Body 示例

```json
{
    "group_id": "123456",
    "message": [
        {
            "type": "file",
            "data": {
                "file": "file://D:/a.jpg",
                "name": "a.jpg"
            }
        }
    ]
}
```

## 响应 (Response)

### 200 OK

成功发送文件消息。

| 参数        | 类型      | 描述                                 |
| ----------- | --------- | ------------------------------------ |
| `status`    | `string`  | 状态，`ok` 表示成功                  |
| `retcode`   | `number`  | 返回码，`0` 通常表示成功             |
| `data`      | `object`  | 响应数据                             |
| `data.message_id` | `number`  | 发送成功后返回的消息ID               |
| `message`   | `string`  | 详细消息或错误信息                   |
| `wording`   | `string`  | 详细提示信息 (人类可读)              |
| `echo`      | `string`  | 可能包含请求时携带的 echo 字段 (可选) |

#### Response Body 示例

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": ""
}
```

## 说明

- `data.file` 字段是发送文件的关键，务必使用支持的格式。
- 消息ID (`message_id`) 可用于后续撤回消息等操作。
