# API 文档: /send_private_msg

## 发送私聊文件消息

此 API 用于向指定用户发送私聊文件消息。文件可以是本地路径、网络链接或 base64 编码。

*   **Endpoint:** `/send_private_msg`
*   **Method:** `POST`
*   **Tag:** 消息相关/发送私聊消息

## 请求 (Request)

*   **URL:** `/send_private_msg`
*   **Method:** `POST`
*   **Content-Type:** `application/json`

**请求体 (Request Body):**

包含以下字段：

| 字段名    | 类型                      | 必填 | 描述                                     |
| :-------- | :------------------------ | :--- | :--------------------------------------- |
| `user_id` | number 或 string          | 是   | 接收私聊消息的用户 QQ 号或其他用户标识。 |
| `message` | array                     | 是   | 消息段数组，必须包含 `file` 类型的消息段。 |

**`message` 数组结构:**

数组中的每个元素都是一个消息段对象。发送文件消息时，必须包含一个 `type` 为 `"file"` 的消息段。

**文件消息段 (`type: "file"`):**

| 字段名    | 类型   | 必填 | 描述                                                                                                                                                              |
| :-------- | :----- | :--- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `type`    | string | 是   | 消息段类型，固定为 `"file"`。                                                                                                                                     |
| `data`    | object | 是   | 文件数据对象。                                                                                                                                                    |
| `data.file` | string | 是   | 文件路径或数据。支持以下格式：<br/>- `file://...` 本地文件路径<br/>- `http://...` 或 `https://...` 网络文件 URL<br/>- `base64://...` 或 Data URL base64 编码的文件数据 |
| `data.name` | string | 否   | 文件名，建议提供。                                                                                                                                                |

**请求体示例 (Example Request Body):**

```json
{
    "user_id": "123456",
    "message": [
        {
            "type": "file",
            "data": {
                // 本地路径
                "file": "file://D:/a.jpg",

                // 网络路径示例
                // "file": "http://i0.hdslb.com/bfs/archive/c8fd97a40bf79f03e7b76cbc87236f612caef7b2.png",

                // base64 示例 (仅为示意，非完整有效编码)
                // "file": "base64://iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mNkYAAAAAYAAjCB0C8AAAAASUVORK5CYII=",

                "name": "a.jpg"
            }
        }
    ]
}
```

## 响应 (Response)

*   **成功响应 (Status 200):**

```json
{
    "status": "ok",
    "retcode": 0,
    "data": {
        "message_id": 696124706
    },
    "message": "",
    "wording": "",
    "echo": null
}
```

**响应字段说明:**

| 字段名            | 类型   | 描述                                                                                                |
| :---------------- | :----- | :-------------------------------------------------------------------------------------------------- |
| `status`          | string | 调用状态，`"ok"` 表示成功，`"failed"` 表示失败。                                                      |
| `retcode`         | number | 返回码，`0` 通常表示成功。非零值表示失败，具体含义请参考 OneBot 规范或相关文档。                          |
| `data`            | object | 响应数据对象。                                                                                      |
| `data.message_id` | number | **必填**。发送成功后，该消息在机器人端的 ID。                                                         |
| `message`         | string | 错误信息，当 `status` 为 `"failed"` 时可能包含详细错误描述。                                            |
| `wording`         | string | 错误信息的友好提示，当 `status` 为 `"failed"` 时可能包含。                                            |
| `echo`            | string | 回显字段，如果请求中包含此字段，则响应会原样返回。可为 `null`。                                         |

## 注意事项

*   `message` 字段是一个数组，虽然发送文件消息通常只需要一个 `file` 类型的消息段，但其结构遵循消息段数组的定义。
*   确保提供的文件路径（本地或网络）机器人进程能够访问。
*   支持的文件类型和大小可能受 QQ 协议限制以及机器人运行环境影响。
*   发送 Base64 数据时，请确保编码正确且数据有效。
